package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.38.2 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.38.2) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@$!`0````````````,`*``!````V!8``#0```!XE`````0`!30`(``'
M`"@`&P`:``8````T````-````#0```#@````X`````0````$`````P```!0!
M```4`0``%`$``!<````7````!`````$````!````````````````````J(X`
M`*B.```%```````!``$```"HC@``J(X!`*B.`0"X`@``'`,```8```````$`
M`@```+2.``"TC@$`M(X!`/````#P````!@````0````$````+`$``"P!```L
M`0``3````$P````$````!````%#E=&2PAP``L(<``+"'```,`0``#`$```0`
M```$````+W5S<B]L:6)E>&5C+VQD+F5L9E]S;P``!P````0````!````3F5T
M0E-$``#`K](U!`````0````#````4&%8```````'````"0````4```!.971"
M4T0``&5A<FUV-VAF`````&$```!L```````````````Q````#@``````````
M````.0````\```!!`````````#```````````P```$\```!D`````````"``
M``!.````!@```!X````5`````````$0```!9````8``````````8````/0``
M`%L```!E`````````&@```!J````+P```!,```!:````1@```!8```!?````
M2`````````!+````1P```#8```!>````)@```"H`````````!P```%``````
M````#````"P```!K````70```$T````A````40```&D`````````8@``````
M```9````+@```$(````````````````````2````,P`````````*````8P``
M`"L`````````"0`````````D````.@````````!2````!0```$D````<````
M/`````````````````````````!,`````````#L```!5````9@````````!G
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````!0`````````
M`````````````````````````````````````",````B`````````"D`````
M````"P```"<````H````+0``````````````#0`````````=````&P```#4`
M```:```````````````1`````````#0````R````.````!\`````````````
M``````````````````0```````````````````!#````)0``````````````
M`````!<`````````0````$4````(````````````````````/P````````!4
M``````````````!8```````````````^````5P````````!3`````````$H`
M```0``````````````!6````7````#<```!A````````````````````````
M````````````V!8````````#``L``````+".`0```````P`1`)D`````````
M`````!(````,```````````````2````%```````````````$@```'H#```L
M(@``"````!(`"P`<```````````````B````*P``````````````$@```$,#
M`````````````!(````Q```````````````2````BP,``&"1`0``````$``5
M`#@``````````````!(```"9`P``S"D``"`````2``L`/P``````````````
M$@```%`#`````````````!(```!'```````````````2````M`,``!0T``!D
M````$@`+`(H``````````````!(```#(`P``Q)$!```````0`!4`3P``````
M````````$@```,`#``!@D0$``````!``%`!?```````````````2````;@``
M````````````$@```'0``````````````!(```![```````````````2````
MA0``````````````$@```(\``````````````!(```#'`P``Q)$!```````0
M`!4`F```````````````$@```%<"`````````````!(```">````````````
M```2````I0``````````````$@```+,``````````````!(```#$````````
M```````1````T0``````````````$@```-,#``"P)```,````!(`"P#@`P``
MX"0``&`````2``L`[`,``.`J``"D!@``$@`+`-\``````````````!8```#R
M```````````````2````8@,`````````````$@```/T``````````````!(`
M```&`0``P)$!``0````1`!4`#@$`````````````$@```!<!````````````
M`!(````Y`P`````````````2````(P$`````````````$@```"H!````````
M`````!(```#Y`P``X$```!@!```2``L`/0$`````````````$0```$\!````
M`````````!(```!?`0`````````````2````;0$`````````````$@```'(!
M`````````````!$```"!`0`````````````2````!`0``%R1`0`$````$0`4
M`)`!`````````````!(```"<`0`````````````2````L0$`````````````
M$@```+P!`````````````!(```!U`P``Q)$!```````0`!4`\P(`````````
M````$@```,\!`````````````!(```!'!```V!8````````2``L`W0$`````
M````````$@```.4!`````````````"(```#]`0`````````````2````"0(`
M````````````$@````X$``#$D0$``````!``%0`6!```0"4``,P!```2``L`
M#P(`````````````(@```"4"`````````````!(````P`@`````````````2
M````(P0``/A!``!T`0``$@`+`$$"`````````````!(````M!```8)$!````
M```0`!4`.00``$PA``!H````$@`+`$$$``!(1```D`(``!(`"P!(`@``````
M```````2````1@0``-@6````````$@`+`$\"`````````````!(```!.!```
M-"(``'P"```2``L`6P0``.PI``#T````$@`+`%8"`````````````!(```!M
M!```#"<``(`````2``L`7P(`````````````$@```'`"`````````````!(`
M```"`P`````````````2````=P(`````````````$@```'L$``",)P``8```
M`!(`"P"&`@`````````````2````CP(`````````````$@```)4"````````
M`````!(````L`P`````````````2````F@(`````````````$@```!\#``"$
MD0$`!````!$`%0"B`@`````````````2````5P,`````````````$@```*D"
M`````````````!(```"#!```?$```&0````2``L`L`(`````````````$@``
M`+\"`````````````!$````4`P``&)$!``0````1`!0`C`0``(0Q``"0`@``
M$@`+`#8!`````````````!(```#$`@`````````````2````:0,`````````
M````$@````!L:6)P97)L+G-O`')E86QL;V,`;65M;6]V90!?7V-X85]F:6YA
M;&EZ90!R;61I<@!S=')S='(`<W1R8VAR`'-T<FYC;7``<W1R<F-H<@!B;V]T
M7T1Y;F%,;V%D97(`<&5R;%]C;VYS=')U8W0`86)O<G0`=6YL:6YK`%]?;'-T
M870U,`!P97)L7V9R964`7U]S=&%T-3``7V5X:70`;65M8W!Y`'!E<FQ?9&5S
M=')U8W0`7U]S=&%C:U]C:&M?9F%I;`!03%]D;U]U;F1U;7``4&5R;%]S=E]S
M971P=@!03%]C=7)R96YT7V-O;G1E>'0`<&5R;%]A;&QO8P!C;&]S961I<@!E
M;G9I<F]N`')E861L:6YK`%]?;W!E;F1I<C,P`&UE;7-E=`!097)L7W-A9F5S
M>7-M86QL;V,`7U]S=&%C:U]C:&M?9W5A<F0`4&5R;%]G=E]F971C:'!V`%]?
M<W!R:6YT9E]C:&L`<F5A9`!03%]M96UO<GE?=W)A<`!097)L7W-Y<U]I;FET
M,P!097)L7V=E=%]S=@!097)L7V-R;V%K7VYO8V]N=&5X=`!097)L7VYE=UA3
M`%!E<FQ?871F;W)K7W5N;&]C:P!097)L7W-Y<U]T97)M`%]?97)R;F\`7U]D
M97)E9VES=&5R7V9R86UE7VEN9F\`4&5R;%]M9U]S970`;6MD:7(`7U]R96=I
M<W1E<E]F<F%M95]I;F9O`'!E<FQ?<&%R<V4`4&5R;%]N97=84U]F;&%G<P!A
M8V-E<W,`9V5T<&ED`&UE;6-H<@!V9G!R:6YT9@!097)L7V%T9F]R:U]L;V-K
M`&UE;6-M<`!097)L7W-V7W-E='!V;@!P97)L7W)U;@!L<V5E:P!O<&5N`'-P
M<FEN=&8`9V5T=6ED`'-T<FQE;@!?7W1L<U]G971?861D<@!?7W-&`'-T<F-M
M<`!L:6)M+G-O+C``;&EB8W)Y<'0N<V\N,0!L:6)P=&AR96%D+G-O+C$`<'1H
M<F5A9%]A=&9O<FL`<W1R9'5P`&QI8F,N<V\N,3(`7U]P<F]G;F%M90!?7W!S
M7W-T<FEN9W,`7U]G971P=W5I9#4P`%]?<WES8V%L;`!?7W-T<&-P>5]C:&L`
M871E>&ET`%]L:6)C7VEN:70`<W1R=&]K`%]?<F5A9&1I<C,P`%]E;F0`<&%R
M7V-U<G)E;G1?97AE8P!?7V)S<U]S=&%R=%]?`&=E=%]U<V5R;F%M95]F<F]M
M7V=E='!W=6ED`'!A<E]C;&5A;G5P`%]E9&%T80!?7V)S<U]E;F1?7P!P87)?
M8F%S96YA;64`<&%R7V1I<FYA;64`<&%R7VUK=&UP9&ER`'-H85]U<&1A=&4`
M;7E?<&%R7W!L`%]?96YD7U\`<&%R7VEN:71?96YV`'-H85]F:6YA;`!?7V)S
M<U]S=&%R=`!X<U]I;FET`&UA:6X`7U]S=&%R=`!P87)?9FEN9'!R;V<`<&%R
M7W-E='5P7VQI8G!A=&@`<&%R7V5N=E]C;&5A;@!P87)?9&EE`'-H85]I;FET
M`%A37TEN=&5R;F%L<U]005)?0D]/5``O=7-R+W!K9R]L:6(O<&5R;#4O-2XS
M."XP+V5A<FUV-VAF+6YE=&)S9"UT:')E860M;75L=&DO0T]213HO=7-R+W!K
M9R]L:6(``*B.`0`7````K(X!`!<```"\D`$`%P```,20`0`7````S)`!`!<`
M``#<D`$`%P```."0`0`7````Z)`!`!<```#PD`$`%P````"1`0`7````")$!
M`!<````0D0$`%P```!21`0`7````&)$!`!<````<D0$`%P```"R1`0`7````
M,)$!`!<````XD0$`%P```#R1`0`7````0)$!`!<```!$D0$`%P```$B1`0`7
M````4)$!`!<```!4D0$`%P```%R1`0`7````P)`!`!4'``#(D`$`%10``-"0
M`0`5(@``U)`!`!$G``#8D`$`$B<``.20`0`5,@``[)`!`!4V``#TD`$`%3P`
M`/B0`0`50@``_)`!`!5'```$D0$`%58```R1`0`59@``L(\!`!8#``"TCP$`
M%@0``+B/`0`6!0``O(\!`!8'``#`CP$`%@@``,2/`0`6"0``R(\!`!8*``#,
MCP$`%@P``-"/`0`6#@``U(\!`!8/``#8CP$`%A```-R/`0`6$@``X(\!`!86
M``#DCP$`%A<``.B/`0`6&```[(\!`!89``#PCP$`%AH``/2/`0`6&P``^(\!
M`!8=``#\CP$`%AX```"0`0`6'P``!)`!`!8@```(D`$`%B$```R0`0`6(P``
M$)`!`!8H```4D`$`%BD``!B0`0`6*@``')`!`!8L```@D`$`%BT``"20`0`6
M+@``*)`!`!8O```LD`$`%C```#"0`0`6,P``-)`!`!8T```XD`$`%C4``#R0
M`0`6-P``0)`!`!8Y``!$D`$`%CH``$B0`0`6.P``3)`!`!8^``!0D`$`%C\`
M`%20`0`600``6)`!`!9"``!<D`$`%D,``&"0`0`61```9)`!`!9'``!HD`$`
M%D@``&R0`0`620``<)`!`!9+``!TD`$`%D\``'B0`0`640``?)`!`!94``"`
MD`$`%E<``(20`0`66```B)`!`!99``",D`$`%EL``)"0`0`67```E)`!`!9=
M``"8D`$`%EX``)R0`0`67P``H)`!`!9A``"DD`$`%F(``*B0`0`68P``K)`!
M`!9E``"PD`$`%FD``+20`0`6:@``N)`!`!9K```$X"WE!."?Y0[@C^`(\+[E
M]'L!``#&C^(7RHSB]/N\Y0#&C^(7RHSB[/N\Y0#&C^(7RHSBY/N\Y0#&C^(7
MRHSBW/N\Y0#&C^(7RHSBU/N\Y0#&C^(7RHSBS/N\Y0#&C^(7RHSBQ/N\Y0#&
MC^(7RHSBO/N\Y0#&C^(7RHSBM/N\Y0#&C^(7RHSBK/N\Y0#&C^(7RHSBI/N\
MY0#&C^(7RHSBG/N\Y0#&C^(7RHSBE/N\Y0#&C^(7RHSBC/N\Y0#&C^(7RHSB
MA/N\Y0#&C^(7RHSB?/N\Y0#&C^(7RHSB=/N\Y0#&C^(7RHSB;/N\Y0#&C^(7
MRHSB9/N\Y0#&C^(7RHSB7/N\Y0#&C^(7RHSB5/N\Y0#&C^(7RHSB3/N\Y0#&
MC^(7RHSB1/N\Y0#&C^(7RHSB//N\Y0#&C^(7RHSB-/N\Y0#&C^(7RHSB+/N\
MY0#&C^(7RHSB)/N\Y0#&C^(7RHSB'/N\Y0#&C^(7RHSB%/N\Y0#&C^(7RHSB
M#/N\Y0#&C^(7RHSB!/N\Y0#&C^(7RHSB_/J\Y0#&C^(7RHSB]/J\Y0#&C^(7
MRHSB[/J\Y0#&C^(7RHSBY/J\Y0#&C^(7RHSBW/J\Y0#&C^(7RHSBU/J\Y0#&
MC^(7RHSBS/J\Y0#&C^(7RHSBQ/J\Y0#&C^(7RHSBO/J\Y0#&C^(7RHSBM/J\
MY0#&C^(7RHSBK/J\Y0#&C^(7RHSBI/J\Y0#&C^(7RHSBG/J\Y0#&C^(7RHSB
ME/J\Y0#&C^(7RHSBC/J\Y0#&C^(7RHSBA/J\Y0#&C^(7RHSB?/J\Y0#&C^(7
MRHSB=/J\Y0#&C^(7RHSB;/J\Y0#&C^(7RHSB9/J\Y0#&C^(7RHSB7/J\Y0#&
MC^(7RHSB5/J\Y0#&C^(7RHSB3/J\Y0#&C^(7RHSB1/J\Y0#&C^(7RHSB//J\
MY0#&C^(7RHSB-/J\Y0#&C^(7RHSB+/J\Y0#&C^(7RHSB)/J\Y0#&C^(7RHSB
M'/J\Y0#&C^(7RHSB%/J\Y0#&C^(7RHSB#/J\Y0#&C^(7RHSB!/J\Y0#&C^(7
MRHSB_/F\Y0#&C^(7RHSB]/F\Y0#&C^(7RHSB[/F\Y0#&C^(7RHSBY/F\Y0`0
MH.$"`*#A!]#-XSD``.I,$)_E#<"@X4@@G^4!$(_@1#"?Y3#8+>D#,(_@`B"1
MYP2P3.("`%/A,*B=*`-0X.$"4(7@`U#%XP1`0^(#4(7@!#"TY3/_+^$%`%3A
M^___&C"HG>BH>`$`&`$``*1W`0!T()_E#<"@X7`0G^5P,)_E`B"/X/#8+>D$
ML$SB`4"2YP,PDN<#`%3A\*B=*`0@U.6@`%+C#P``&@A`A.('<(/B!'!'X`=P
MQ^,$<(?@"%`4Y01@H.$`,)7E,_\OX0<`5.$``(7E\*B="`0PUN4(0(3BH`!3
MX_3__PHB___K1'@!`#P!```@`0```%!1XG2!G^4-P*#A"("/X(#8+>D$L$SB
M#-!-XDL```I<(9_E`,"5Y5@QG^4"$)CG`""<Y0!0@>4``%+C`V"8YP@PE>4`
M,(;E.@``"C@QG^4#$)CG`""!Y0`@G.4`,-+E``!3XP4```H!((+B+P!3XP`@
M@04!,-+D``!3X_K__QH``%#C````"O#^_^N+___K^#"?Y0,PF.<``%/C-0``
M"NP@G^7L,)_E`B"8YP,PC^`"`%/A"```*@-PX.$"<(?@`W#'XP1`0^(#<(?@
M!#"TY3/_+^$'`%3A^___&K@`G^4``(_@V?[_Z[`@G^6P,)_E`B"8YP,PC^`"
M`%/A"```*@-PX.$"<(?@`W#'XP1`0^(#<(?@!#"TY3/_+^$$`%?A^___&@`@
MEN4`$)7E!`"5Y=`*`.NJ_O_K3""?Y60PG^4"()CG`S"/X``P@N7+___J5#"?
MY1,@H.,$`*#C`""-Y0,PC^`"(*#C`!"@X_/^_^L!`*#CT/[_ZW[__^O'___J
MP'<!`&0!```X`0``;`$``%P!```H`0``)'8!`##^__]$`0``W'4!`&1X`0"@
M+0``#<"@X=0PG^7PVRWI`(!0X@2P3.(!<*#A`S"/X"L```J\()_E`C"3YP"0
MD^4``%GC*```"@`PV.4]4%/B`5"@$P``4^,`4*`#``!5XQ$``!H`0)GE``!4
MXPP```H)8*#A!2"@X0@0H.$$`*#AB/[_ZP``4.,"```:!3#4YST`4^,+```*
M!$"VY0``5./S__\:!`"@X?"KG>@(4*#A`3#UY0``4^,]`%,3^___&@A01>#F
M___J`5"%X@E@1N`%0(3@1F&@X0!@A^4$`*#A\*N=Z`A`H.'M___J"4"@X>O_
M_^H$=@$`.`$```W`H.&0,)_E\-@MZ02P3.*(<)_E"-!-XB1`2^('<(_@`%"@
MX0-@E^<`,);E(#`+Y000H.$%`*#AMO__ZP``4.,.```*6#"?Y200&^4#,)?G
M`""3Y0$Q@N`$`)/E``!0XP$!@N?Q__\*!#"#X@0@D^4``%+C!""#Y/O__QKK
M___J("`;Y0`PEN4#`%+A`0``&AS02^+PJ)WH;?[_ZT`!```8=0$`.`$``$0Q
MG^4-P*#A0"&?Y0,PC^#PWRWI!+!,XJS03>("0)/G`&!0X@`PE.4P,`OE`@``
M"@`PUN4``%/C!0``&C`@&^4`,)3E`P!2X3X``!HHT$OB\*^=Z&;^_^L`<%#B
M]O__"NR`G^7,,$OBZ)"?Y=0P"^4(@(_@X#"?Y0F0C^`#,(_@T#`+Y0<`H.'+
M_O_K``!0XR4```H-4(#B"!"@X04`H.'"_O_K``!0X_7__PH)$*#A!0"@X;W^
M_^L``%#C\/__"@8`H.&P_O_K`*"@X04`H.&M_O_K``"*X`(`@.*P_O_K!3"@
MX08@H.'0$!OE`*"@X9S^_^O4$!OE"@"@X1O^_^L!`'#C"@"@X0,```K$,!OE
M#SH#X@$)4^,(```*"O[_ZPH`H.'__?_KU?__Z@<`H.$I_O_K!@"@X>7]_^N^
M___JKO__Z_7__^H7_O_K@'0!`$`!``!X*P``="L``'0K```-P*#A'#*?Y?#?
M+>D$L$SB%)*?Y1303>(`(-'E"9"/X`%`H.$]`%+C`%"@X0-@F><!0($"!`"@
MX0`PEN4P,`OE>?[_ZS002^(`<*#A!0"@X2[__^L`@%#B/@``"G+^_^L'`%#A
M-0``*L`QG^4T@!OE`Y"9YPB!H.$`,-7E/0!3X@$`H!,``%/C``"@`P``4.,%
M```*!0"@X0$P\.4``%/C/0!3$_O__QH%`$#@`G"'X@"@F>4``(?@8?[_ZP``
M4.,(`(KG5```"@`@F>4!$(7B-``;Y0`PU>4``9+G/0!3XP``4Q,`,,#E!@``
M"@$@@.(!,-'D`@"@X3T`4^,``%,3`3#"Y/G__QH`(*#A/3"@XP`PP.4!,-3D
M``!3XP$PXN7[__\:``"@XS`@&^4`,);E`P!2X3H``!HHT$OB\*^=Z`$P2.(!
M(-3D``!2XP$@X^7[__\:\O__ZM`PG^4#D)GG`""9Y0"@DN4``%KC"!"@`PD`
M``H(,*#A`A"@X0```.H*,*#A!`"QY0&@@^(``%#C^O__&@,P@^(#$:#AD#"?
MY0,PC^```)/E``!0XQ,``!H!`*#A/"`+Y0$0H.,`$(/E'_[_ZP`P4.(X,`OE
M$@``"CP@&^4*@:#A`A"@X0@@H.%=_?_K.#`;Y0`PB>4!((KB`!"@XP(1@^<T
MH`OEG?__Z@(`H.%1_?_K``!0XP`PH.$``(GE"H&@$?/__QH``.#CP/__ZHC]
M_^M``0``$',!`#@!``"8<P$`@#"?Y0W`H.%\()_E`S"/X##8+>D$L$SBH-!-
MX@)`D^>T$$OB`%"@X0`PE.48,`OE8OW_ZP``4.,``*`3!```&JPP&^4/.@/B
M"@I3XP$)4Q,%```*&"`;Y0`PE.4#`%+A!P``&A302^(PJ)WH!0"@X0(0H..T
M_?_K$`]OX:`"H.'S___J8OW_Z^AP`0!``0```#&?Y0W`H.'PWRWI!+!,XO3`
MG^4#,(_@`=M-XD-.2^(,T$WB#("3YP!0H.'<`)_E`6"@X?\C`.,$$*#A`#"8
MY0``C^`P,`OE7/W_ZP"@4.(B``#:N`"?Y0%P2N(``(_@POW_ZRPP2^(',(/@
M!#13Y0``4^,`D)#E$0``"@IPH.$'(*#A+Q"@XP0`H.&0_?_K``!0XPP```H'
M,*#A!""@X040H.$)`*#AE?W_ZS`@&^4`,)CE`P!2X1$``!HHT$OB\*^=Z```
M5^/L__\:!B"@X040H.$)`*#A+/W_Z_+__^HP`)_E``"/X*#]_^L&(*#A!1"@
MX0"0D.4)`*#A(_W_Z^G__^H>_?_K4'`!`$`!``"0)P``.'$!`+!P`0#D,)_E
M#<"@X3#8+>D$L$SBV,"?Y0,PC^`!VTWB04Y+X@C03>(,4)/G"$!$X@`0H.$!
M*Z#C!`"@X0`PE>48,`OEU?S_ZP0`0.`!`$#B`#"$X`0`4^$*``":`"#4YR\`
M4N,'```:`!"@XP(``.H`(-/E+P!2XP(``!H!$$/D!`!3X?G__QHO$*#C!`"@
MX='\_^L``%#C"@``"@0`4.$`,*"#`##`A00`H.%+_?_K&"`;Y0`PE>4#`%+A
M"@``&A302^(PJ)WH&"`;Y0`PE>4#`%+A!```&A@`G^4``(_@%-!+XC!HG>@\
M_?_JWOS_ZS1O`0!``0``S"4``$P@G^4-P*#A2#"?Y4@`G^4"((_@\-@MZ02P
M3.(``(_@`V"2YTS]_^LP4)_E,$"?Y050C^`&(*#A!$"/X`4PH.$$$*#A``"0
MY1S02^+P:)WH]OS_ZD!N`0`D`0``9&\!`&@E``"8)0``7`"?Y0W`H.$PV"WI
M``"/X`C03>($L$SB2$"?Y33]_^L$0(_@`%"@X0``D.79___K-""?Y0``E>4`
M$*#C+#"?Y0(@E.<$$(WE`S"/X"`0G^4`,(WE`1"/X/7\_^L4T$OB,*B=Z`QO
M`0#(;0$`<`$```@H```P)0````"@XQ[_+^%(,I_E#<"@X40BG^4#,(_@\-\M
MZ1/=3>($L$SB#-!-X@(PD^<`0*#A$WU+XB0"G^4,<$?BX#0+Y0%@H.$`,)/E
M!!!'X@``C^`P,`OEOOW_ZR\0H.,`4*#A!`"@X5S\_^L``%#C"P``"NP!G^4$
M$*#A``"/X'#^_^L$`*#AX#0;Y3`@&^4`,)/E`P!2X6X``!HHT$OB\*^=Z`8`
MH.'6_/_KN!&?Y0$0C^!__/_K`)!0XNS__PJH,9_EJ*&?Y0,PC^#<-`OEH#&?
MY0J@C^"<@9_E`S"/X.0T"^64,9_E"("/X`,PC^#8-`OE`##9Y0``4^,\```*
M``!5XP0```H)$*#A!0"@X>#\_^L``%#C+0``"@D`H.'3_/_K`1!`X@!@H.$!
M,(G@`P!9X0T``"H!$-GG+P!1XPH``!H``*#C`@``Z@`@T^4O`%+C`@``&@$`
M0^0#`%GA^?__&@D`H.'!_/_K`&"@X00`H.&^_/_K!@"`X`$`@.(!"U#CNO__
M*M@T&^5#;DOB`2N@XP`0H.,(0(WE!@"@X00PC>4*,*#A`)"-Y5G\_^L'$*#A
M!@"@X2;\_^L``%#C`P``&L0T&^4/.@/B`@E3XQ$```H($*#A``"@XS7\_^L`
MD%#BHO__"@`PV>4``%/CPO__&@``5>,3```*W!0;Y04`H.&C_/_K``!0XP%@
MH!/<E!L5[O__"M3__^H!$*#C!@"@X6C\_^L``%#CZ/__&DP`G^4&$*#A``"/
MX`'^_^L&`*#A;_S_ZX[__^H!8*#CY)0;Y<7__^H-_/_K7&T!`$`!``#8)```
MN"0``)0D```()```="0``/0C``!<)```("<``/PB```-P*#A+Q"@XS#8+>D$
ML$SB`$"@X=C[_^L``%#C`4"`$@0`H.$4T$OB,&B=Z%/\_^H-P*#A,-@MZ0!`
M4.($L$SB"@``"@`PU.4``%/C!P``"F7\_^L!`(#B`0M0XP@``(H$`*#A%-!+
MXC!HG>C,_O_J%`"?Y0``C^`4T$OB,&B=Z#[\_^H``*#C,*B=Z-0A``!L(9_E
M#<"@X6@QG^4"((_@9`&?Y7#8+>D$L$SB#-!-X@-0DN<``(_@4&&?Y21`2^(`
M,)7E!F"/X"`P"^4Y_?_K/`&?Y0``C^`V_?_K-`&?Y0``C^`S_?_K+`&?Y0``
MC^`P_?_K)`&?Y0``C^`M_?_K'`&?Y0``C^`J_?_K%`&?Y0``C^`G_?_K#`&?
MY0``C^`D_?_K!@"@X2+]_^O\`)_E``"/X!_]_^OT`)_E``"/X!S]_^OL`)_E
M!!"@X0``C^#>_/_K`!!0X@$```H&`*#AEOW_Z]``G^4$$*#A``"/X-;\_^L`
M$%#B`@``"KP`G^4``(_@C?W_Z[0`G^4$$*#A``"/X,W\_^L`$%#B#0``"J``
MG^4``(_@A/W_ZY@0G^68`)_E`1"/X```C^!__?_K("`;Y0`PE>4#`%+A"P``
M&AC02^)PJ)WH=`"?Y000H.$``(_@N?S_ZP`04.+N__\*8`"?Y0``C^!P_?_K
MZO__ZH'[_^M0:@$`0`$``!0B``!4(@```"(``/PA``#\(0``^"$``/PA``"0
M(0``\"$``/0A``!P(0``Y"$``-@A``#8(0``U"$``/P@```X(P``."$``)0A
M```8(0``;#"?Y0W`H.%H()_E`S"/X&0`G^40V"WI!+!,X@S03>("0)/G'!!+
MX@``C^``,)3E&#`+Y8[\_^L``%#C!0``"@``T.4``%#C,`!0$P$`H`,``*`3
M`0`@XA@@&^4`,)3E`P!2X0$``!H0T$OB$*B=Z$[[_^N$:`$`0`$``(@@```-
MP*#A#P`MZ40PG^4`V"WI%+!,XCS`G^4#,(_@"-!-XC0`G^4(X(OB#,"3YQ3@
M"^4.(*#A!!";Y0#`G.40P`OE``"3Y[``@.*/^__K_P"@X_3Z_^OX9P$`0`$`
M`&@!``#$$9_E#<"@X?#?+>D$L$SBN,&?Y0$0C^`!V$WB`N"@XR303>(,$)'G
M`<A+XD3`3.(`(*#C`#"@XP"`H.$`$(SE`'"@XP#@C>4`$)'E,!`+Y83[_^L!
M0%#B`%#!XL5OH.$&`*#AQA^@X09@).`!,"?@`"!6X')@_^8`(";@`"!2X`$P
MP^`"0%3@`U#%X```5.,`,-7B!&"@X05PH.%!``"Z+%&?Y0$H2^(!2$OB)#&?
MY4`@0N((D*#C!5"/X`&00.,X0$3B`S"/X``P@N4`$*#C!B"@X0<PH.$`$(WE
M"`"@X6#[_^L`,.#C`"#@XP,`4>$"`%`!+@``"@D@H.$$$*#A"`"@X17[_^L!
M`'#C&@``"@<`4.,;``":"`!`X@"@E.`#```Z%P``Z@&@2N($`%KA%```.@@@
MH.,%$*#A"@"@X3S[_^L``%#C]O__&@1`2N`$`);@Q!^GX`$X2^(P(!OE1#!#
MX@`PD^4`,)/E`P!2X10``!HHT$OB\*^=Z%@`G^4``(_@A?__ZP%H5N(`(*#C
M`'#'XO\O3^,`,.#C`P!7X0(`5@'(__\:``#@XP`0X./H___J`3A+XD`P0^(`
M`)/E=O__Z\O__^K`^O_KG&<!`$`!``!T:`$`B!\``-P>```-P*#A`-@MZ02P
M3.(I^__K(OO_ZP``4.,``)`5`*B=Z-0PG^4-P*#AT""?Y0,PC^#PV2WI!+!,
MXA303>("0)/G`%"@X;A@G^4L$$OB`#"4Y09@C^`&`*#A*#`+Y=3[_^L%$*#A
M`'!0XAD```H`,-?E``!3XQ8```IL^O_K``!0XQ8``!H%`*#A$/O_ZP"`H.$'
M`*#A#?O_ZP``B.`"`(#B$/O_ZUPPG^5<$)_E!2"@X0!PC>4#,(_@`1"/X`"`
MH.'Y^O_K"!"@X08`H.%T_/_K`@``ZC0`G^4``(_@</S_ZR@@&^4`,)3E`P!2
MX0$``!H@T$OB\*F=Z'SZ_^ND90$`0`$``#@>``#L'```[!P``+`=```-P*#A
M(#:?Y?#?+>D$L$SB&,:?Y44?2^)+WTWB#,"/X#@!"^4,((SB0!$+Y0'@H.'\
MA9_E!P"2Z`B`C^`8<(SB2V]+X@.0F.<PP(SB$DY+XA->2^('`(;H#P"WZ#R1
M"^4`D)GE#P"NZ`,`E^@PD`OE`P".Z`<`G.@'`(3H!1"@X;`%G^4``(_@A/O_
MZP!P4.("```*`##7Y0``4^.+```:D?__ZP"@4.*-```*"@"@X<'Z_^N``*#A
M`0"`XL3Z_^L`(-KE``!2XP"0H.$)```*9'6?Y0E`H.$'<(_@!`"@X0<0H.&K
M^O_K`2#ZY0)`A.(``%+C^/__&A0!&^4``%#C$@``"D!!&^4"``#J!`"TY0``
M4.,-```*!1"@X5_[_^L`<%#B^/__"@`PU^4``%/C]?__"J/\_^L``%#C\O__
M"@<`H.&!^O_K`*!0XA<``!H`<*#C+#!+X@<Q@^``01/E``!4XPH```H`,-3E
M``!3XP<```H$`*#A`7"'XI'\_^L``%#C!```&@=!EN<``%3C]/__&@"@H.,$
M``#J!`"@X6KZ_^L``%#CZ?__"@"@H.$*`*#A@/K_ZP!`H.$)`*#A??K_ZP``
MA.`!2X#B!$"$X@0`H.%^^O_K8!2?Y6`TG^4*(*#A`1"/X``0C>54%)_E`S"/
MX`20C>4!$(_@`'"@X63Z_^L'`*#A!QV@XS3Z_^L!`'#C&@``"OP02^('`*#A
MV/G_ZP!@4.(#```:]#`;Y0\Z`^(!"5/C0P``"@@$G^4',*#A."$;Y0!`H./\
M$Y_E``"8YP`@DN4!$(_@L`"`XM3Y_^L\,1OE!`"@X3`@&^4`,)/E`P!2X>H`
M`!HHT$OB\*^=Z`WZ_^L`,)#E$0!3X^#__PHX,1OE`$"3Y0?Z_^NDPY_E!S"@
MX:03G^4$(*#A`$"@XPS@F.<!$(_@`,"0Y;``CN(`P(WENOG_Z^3__^H-___K
M!P"@X1SZ_^L`0*#AW___Z@IPH.$'D83@!)!)X@0`N>4``%#C#```"@40H.$!
M<(?BY?K_ZP`P4.+W__\*`##3Y0``4^/T__\*"_K_ZP``4./O__\*`*"@X5[_
M_^H-`*#C'*.?Y27Z_^M3(*#C"J"/X`"0H.%@___JX)`;Y1/Z_^L``%GAM___
M&O0P&^53,.CG!PU3X[/__QH$`*#A%_K_ZP40H.$`0*#AV`*?Y0``C^#%^O_K
M`!!0XE(```HX,1OE``"3Y>W\_^L`4%#B30``"@4`H.$#^O_K`P!0XP"`H.$,
M``":H!*?Y00`0.(``(7@`1"/X`3Z_^L``%#C!0``&@0`6.."```*"("%X`4P
M6.4O`%/C?@``"@[^_^L`H%#B!```&@4`H.$*$*#AWOG_ZP!04.(V```:4!*?
MY5`"G^4!$(_@3)*?Y0``C^!(@I_E6?O_ZT12G^6[^?_K0!*?Y4`RG^4'(*#A
M`1"/X`00C>4T$I_E`S"/X`F0C^`(@(_@`1"/X`50C^```(WE!`"@X<OY_^L-
M``#JD_G_ZP`PD.41`%/C#@``&J?Y_^L!8(;B"%"-Y0DPH.$$8(WE!R"@X0@0
MH.$``(WE!`"@X;SY_^L'':#C!`"@X8SY_^L!`'#C[/__"@<`H.$E^?_KO`&?
MY000H.$``(_@+_O_ZP0`H.&,_O_K8?__ZC@Q&^4`4)/EKO__Z@?^_^L``%#C
M`("@X0`PT>(!D*#APO__N@H@4.)D,$OB`*"-Y04`H.$X,0OE`##!XI7Y_^LX
M$1OE!B"@XP4`H.%/^?_K!@!0XP(```I,`9_E``"/X-K]_^M$,9_E9"`;Y0,P
MC^`,$(/B##"3Y0,`4N&K__\:.#$;Y;0@T^&T,-'A`P!2X:;__QHR(%CB7&!+
MX@`PR>(`$*#C!0"@X0`0C>5Y^?_K!0"@X080H.$H(*#C,_G_ZR@`4.,"```*
MY`"?Y0``C^"^_?_KW!"?Y0<@H.'8,)_E!`"@X0$0C^`$$(WES!"?Y0,PC^``
M8(WE`,"@XP$0C^`TP$OE;/G_Z[/__^HX,1OE!("3Y0``6.-\__\*"`"@X6[Y
M_^L#`%#C>/__FI`0G^4$`$#B``"(X`$0C^!P^?_K``!0XPA0H`%P___JZ_C_
MZT`!```<9@$`A&0!`.P;``"T'```O!L``&0=``"<&P``:`$``(P;``#P&@``
M1!H``+@:``!\&@``J!H``,`8```(&P``+!H``,P:``#H&@``#!L``!@:``"H
M%P``&!D``+P6``"H&```9!D``(@9``"$&```-!@``#PBG^4-P*#A.#*?Y0(@
MC^`T`I_E\-DMZ02P3.(,T$WB`V"2YP``C^`L4$OB`#"6Y2@P"^4Z^?_K!1"@
MX0`PD.4(`I_E9"#3Y0``C^!E(,/EZ?G_ZP``4.,"```*`##0Y3$`4^->```*
MT_S_Z^`!G^7@09_E``"/X"GY_^L$0(_@`S"@XP$@H.,$$*#A`'"@X0``D.7%
M^/_K`$!0X@H```H,,)3EL"&?Y0``E^4`$)/E`B"/X*+X_^L,,)3E`!"3Y0@P
MD>4!!1/C40``&HP!G^6,09_E``"/X!'Y_^L$0(_@`S"@XP$@H.,$$*#A`'"@
MX0``D.6M^/_K`$!0X@D```I@`9_E!1"@X0``C^"Z^?_K`"!0XC8```H,,)3E
M``"7Y0`0D^6&^/_K/`&?Y3R!G^4``(_@^OC_ZS01G^4!(*#C"("/X`$0C^``
M<)#E`$"@X0<`H.&A^/_K&"&?Y0(@C^``$*#A!P"@X77X_^L`,)3E!`&?Y0`@
MH.,%$*#A``"/X&4@P^6<^?_K``!0XP@`B.4+```*!QV@XZCX_^L!,(#B$0!0
MXP$`4Q,=``"**"`;Y0`PEN4#`%+A&```&B#02^+PJ9WH!`"8Y>/]_^L``%#C
M"`"(Y>[__QJ@`)_E``"/X('X_^L!,-#E``!3XY[__PJ<___JB#"?Y0P@E.4#
M,(_@!#"3Y0``DN4`$)/EZ/K_Z\3__^H``)?EA?C_ZZK__^I$^/_K7""?Y0`P
MH.%8`)_E`B"/X```C^`&`)+I`!"1Y6GX_^L,7@$`0`$``"1?`0#4%0``U%X!
M`'`7``!`%P``=%X!`!P7``#0%```&%X!`.1>`0"X%@``N!8``%`4``!`%@``
M*%X!`/1=`0`,%@``#<"@X3#8+>D$L$SB`$"@X;C\_^L``%#C``!4$S"HG0@`
M,-3E``!3XS"HG0@$`*#A)?S_ZQC\_^L@$)_E!""@XP$0C^#M]__K``!0XS"H
MG1@$`*#A%-!+XC!HG>BF^?_J+!0``/0[G^4-P*#A\-\MZ0,PC^#HZY_E!+!,
MXE7?3>(73DOB'""`X@XPD^=<P(#B!!"@X7@Q"^4`,)/E,#`+Y00PDN0"`%SA
M,S^_Y@0P@>3Z__\:_$"$XEWO2^(.(*#A!!"^Y3@PDN4DP)+E!`!>X0P@DN4,
M,"/@`C`CX`$P(^#C/Z#A0#".Y?/__QIP<1OEF3D'XP00D.6".D7C$."0Y0-P
MA^`(4)#EH2L.XPQ`D.4.<(?@`&"0Y6&1H.$$X)#E!!`EX&S!&^79+D;C#A`!
MX&:!H.$)X"7@!!`AX&BA&^7F?8?@`7"'X`/`C.`($"G@!N`.X`<0`>`$P(S@
M`Z"*X`7@+N`,X([@!:"*X`G`(>#G[8[@"L",X&=QH.%DH1OE!Q`HX`X0`>#N
MS8S@`Z"*X`@0(>`)D(K@;N&@X0D0@>!@D1OE#J`GX.P=@>`,H`K@`Y")X&S!
MH.$(D(G@!X`JX%RA&^4)@(C@#)`NX`.@BN`!D`G@X8V(X`Z0*>!A$:#A!W"*
MX%BA&^4'<(G@`9`LX.A]A^`#H(K@")`)X`R0*>`.X(K@:(&@X0[@B>!4D1OE
M"*`AX`>@"N#G[8[@`Y")X&=QH.$,D(G@`<`JX%"A&^4)P(S@!Y`HX.[-C.`#
MH(K@#I`)X`$0BN`(H"G@;N&@X0$0BN!,H1OE#I`GX`R0">#L'8'@`Z"*X`>0
M*>`(@(K@;,&@X0B0B>!(@1OE#*`NX.&=B>`!H`K@`X"(X&$1H.$'@(C@#G`J
MX$2A&^4(@(?@`7`LX`.@BN`)<`?@Z8V(X`[@BN!ID:#A0*$;Y0QP)^`.<(?@
M">`AX`.@BN`(X`[@#,"*X`'@+N#H?8?@#.".X&B!H.$\P1OE"*`IX.?MCN`'
MH`K@`\",X&=QH.$!P(S@"1`JX#BA&^4,P('@!Q`HX`.@BN`.$`'@"9"*X`B@
M(>#NS8S@"9"*X&[AH.$TH1OE#A`GX.R=B>`#H(K@#!`!X`<0(>!LP:#A"("*
MX#"A&^4(@('@#!`NX`.@BN`)$`'@Z8V(X`X0(>!ID:#A!W"*X"RA&^4'<('@
M"1`LX.A]A^`#H(K@"!`!X`P0(>!H@:#A#N"*X"BA&^4.X('@"!`IX`.@BN`'
M$`'@#*"*X`D0(>#G[8[@"A"!X&=QH.$DH1OE!\`HX.X=@>`#,(K@#L`,X""A
M&^4(P"S@;N&@X0DP@^`#,(S@`I"*X`[`)^`<H1OEX3V#X`B0B>`!P"S@88&@
MX0@0+N`,P(G@`I"*X!BA&^7CS8S@!W")X`,0(>!C,:#A`I"*X`$0A^`4H1OE
M`W`HX.P=@>`.X(G@#'`GX&S!H.$"D(K@!W".X!"A&^4,X"/@X7V'X`B`B>`!
MX"[@81&@X0&0+.`.X(C@`H"*X`RA&^7G[8[@`X"(X`<P*>!G<:#A!Y`AX`,P
MB.`"@(K@"*$;Y>X]@^`,@(C@#L`IX&[AH.$.D"?@#,"(X`*`BN`$H1OEX\V,
MX`&`B.`#$"G@8S&@X0.0+N`!$(C@`H"*X`"A&^7L'8'@!X"(X`QP*>!LP:#A
M#)`CX`=PB.`"@(K@_*`;Y>%]A^`.@(C@`>`IX&$1H.$!D"S@#N"(X`*`BN#X
MH!OEY^V.X`.`B.`',"G@9W&@X0>0(>`#,(C@`H"*X/2@&^7N/8/@#("(X`[`
M*>!NX:#A#I`GX`S`B.`"@(K@\*`;Y>/-C.`!@(C@`Q`IX&,QH.$#D"[@`1"(
MX`*`BN#LH!OE[!V!X`>`B.`,<"G@;,&@X0R0(^`'<(C@`H"*X.B@&^7A?8?@
M#H"(X`'@*>!A$:#A`9`LX`[@B.`"@(K@Y*`;Y>?MCN`#@(C@!S`IX&=QH.$'
MD"'@`S"(X`*`BN#@H!OE[CV#X`R`B.`.P"G@;N&@X0Z0)^`,P(C@`H"*X-R@
M&^7CS8S@`8"(X`,0*>!C,:#A`I"*X`$0B.#8H!OE`X`NX.P=@>`'<(G@#(`H
MX&S!H.$"D(K@"("'X-2@&^4,<"/@X8V(X`%P)^`.X(G@81&@X0?@CN`"H(K@
MT)`;Y0$@+.!H<:#AZ.V.X`.@BN`"@"C@W#P+XQL_2.,'(('A"*"*X`.0B>!N
M@:#A#B`"X`S`B>#N[8K@S)`;Y0>@`>`*H(+A"""'X0S`BN`.(`+@`Z")X`B0
M!^#NS8S@`1"*X&[AH.$)((+AR)`;Y0$@@N`.$(CA#J`(X`.0B>`,$`'@!W")
MX`H0@>'L+8+@!Q"!X&S!H.'$<!OE#)".X>(=@>`#H(?@`I`)X&)QH.$,(`[@
M`B")X<"0&^4(H(K@!X",X0H@@N`!@`C@`Z")X`>0#.#A+8+@"8"(X6$1H.$.
MX(K@O)`;Y0[@B.`!@(?A`:`'X`*`".`#D(G@XNV.X`R0B>!B(:#A"J"(X;B`
M&^4"P('A":"*X`[`#.`#D(C@;H&@X>[MBN`"H`'@!Y")X`K`C.$)P(S@M)`;
MY0AP@N'NS8S@`Z")X`YP!^`(D`+@;N&@X0EPA^$!$(K@L)`;Y0$0A^`.<(CA
M#J`(X`QP!^`#D(G@[!V!X`*0B>!LP:#A"J"'X:QP&^4,(([A":"*X`$@`N`#
MD(?@87&@X>$=BN`,H`[@")")X`H@@N$)((+@J)`;Y0>`C.'A+8+@`Z")X`&`
M".`'D`S@81&@X0F`B.$.X(K@I)`;Y0[@B.`!@(?A`:`'X`*`".`#D(G@XNV.
MX`R0B>!B(:#A"J"(X:"`&^4"P('A":"*X`[`#.`#D(C@;H&@X>[MBN`"H`'@
M!Y")X`K`C.$)P(S@G)`;Y0AP@N'NS8S@`Z")X`YP!^`(D`+@;N&@X0EPA^$!
M$(K@F)`;Y0$0A^`.<(CA#J`(X`QP!^`#D(G@[!V!X`*0B>!LP:#A"J"'X91P
M&^4,(([A":"*X`$@`N`#D(?@87&@X>$=BN`,H`[@")")X`H@@N$)((+@D)`;
MY0>`C.'A+8+@`Z")X`&`".`'D`S@81&@X0F`B.$.X(K@C)`;Y0[@B.`!@(?A
M`:`'X`*`".`#D(G@"J"(X8B`&^7B[8[@#)")X&(AH.$)H(K@`L"!X0.0B.`.
MP`S@;H&@X0=PB>#N[8K@A)`;Y0*@`>`*H(SA",""X0=PBN`#,(G@#L`,X`B0
M`N"`H!OE[GV'X`$P@^!NX:#A"<",X=81#.-B&DSC`\",X`&0BN`.,"C@?*`;
MY>?-C.`"((G@!S`CX&=QH.$!D(K@`S""X'B@&^4'("[@[#V#X`B0B>`,@"+@
M;"&@X0C`B>`"D"?@`8"*X'2@&^7CS8S@#H"(X`/@*>!C,:#A`9"*X`[@B.!P
MH!OE`X`BX.SMCN`'D(G@#(`HX&QQH.$(P(G@!Y`CX`&`BN!LH!OE[LV,X`*`
MB.`.("G@;N&@X0(@B.`.D"?@`8"*X&B@&^7L+8+@`X"(X`PP*>!LP:#A`S"(
MX`R0+N`!@(K@9*`;Y>(]@^`'@(C@`G`IX&(AH.$'<(C@`I`LX`&`BN!@H!OE
MXWV'X`Z`B.`#X"G@8S&@X0[@B.`#D"+@`8"*X%R@&^7G[8[@#("(X`?`*>!G
M<:#A#,"(X`>0(^`!@(K@6*`;Y>[-C.`"@(C@#B`IX&[AH.$"((C@#I`GX`&`
MBN!4H!OE["V"X`.`B.`,,"G@;,&@X0,PB.`,D"[@`8"*X%"@&^7B/8/@!X"(
MX`)P*>!B(:#A!W"(X`*0+.`!@(K@3*`;Y>-]A^`.@(C@`^`IX&,QH.$.X(C@
M`Y`BX`&`BN!(H!OEY^V.X`R`B.`'P"G@9W&@X0S`B.`'D"/@`8"*X$2@&^7N
MS8S@`H"(X`X@*>!NX:#A`B"(X`Z0)^`!@(K@0*`;Y>PM@N`#@(C@##`IX&S!
MH.$#,(C@#)`NX`&`BN`\H!OEXCV#X`>`B.`"<"G@8B&@X0=PB.`"D"S@`8"*
MX#B@&^4.@(C@`^`IX.-]A^`.X(C@`8"*X&,QH.$,P(C@-(`;Y0.0(N#G[8[@
M!Y`IX`$0B.!G<:#A!X`CX`G`C.`&$('@[LV,X`(@@>`.@"C@"(""X!`0D.7L
M+8C@`""`Y7@A&^4#,('@,)`;Y6[AA>`$$)#E!W"$X``@DN4,P('@"."`Y0(`
M6>$0,(#E!,"`Y0QP@.4!```:*-!+XO"OG>@1]?_K&%L!`$`!```-P*#A8`"@
MXP#8+>D$L$SBB/7_ZP$3`N.)*PKC11=&X\TO3N,`$(#E_AP-XP0@@.6Z&$GC
M=B0%XP@0@.4R($'C\!$.XPP@@.72$TSC`""@XQ`0@.44((#E&""`Y5P@@.4`
MJ)WH#<"@X?#;+>D"@*#A%#"0Y8(AH.$`4*#A`4"@X0(PD^`8()#E7`"0Y0`0
MH.,!$*`C``!1XP$@@A(``%#CJ"Z"X`2P3.(4,(7E')"%XA@@A>4/```*0&!@
MX@00H.$&`%CA``")X`A@H+$&(*#AU/3_ZUPPE>4#,(;@7#"%Y4``4^/PJYT8
M!0"@X0:`2.`&0(3@P/S_ZS\`6.,8``#:0(!(XBACH.$!<(;B!W.$X$`@A.($
M$*#A"3"@X0!`D>40$('B#.`1Y1`P@^((P!'E!``1Y0(`4>$00`/E#.`#Y0C`
M`^4$``/E\___&@4`H.$!0*#AJ/S_ZP<`5.'K__\:!H-(X`00H.$)`*#A"""@
MX:ST_^M<@(7E\*N=Z`W`H.'PVRWI'("!XA1@D>4!0*#A&'"1Y0!0H.'6,>7G
M?Q#@XP$@@^($L$SB.`!2XP,0R.<"`(C@20``VD`@8N(`$*#CMO3_ZP0`H.&+
M_/_K"`"@X3@@H.,`$*#CL/3_ZU=PQ.4G+*#A6V#$Y2<XH.%4(,3E!`"@X28L
MH.%5,,3E)W2@X28XH.%6<,3E)F2@X5DPQ.58(,3E6F#$Y7?\_^L#,-3E!`"@
MX0`PQ>6R,-3A`3#%Y0`PE.4C-*#A`C#%Y0`PE.4#,,7E!S#4Y00PQ>6V,-3A
M!3#%Y00PE.4C-*#A!C#%Y00PE.4',,7E"S#4Y0@PQ>6Z,-3A"3#%Y0@PE.4C
M-*#A"C#%Y0@PE.4+,,7E#S#4Y0PPQ>6^,-3A#3#%Y0PPE.4C-*#A#C#%Y0PP
ME.4/,,7E$S#4Y1`PQ>6R,=3A$3#%Y1`PE.4C-*#A$C#%Y1`PE.43,,7E)-!+
MXO!KG>@V]/_J."!BX@`0H.-L]/_KNO__ZF@PG^4-P*#A,-@MZ0,PC^!<0)_E
M!+!,XB0@T^4$0(_@``!2XS"HG1A(()_E`1"@XR00P^4",)3G``!3XP(```HT
M,)_E`P"?YP?T_^LL,)_E`S"4YP``4^,PJ)T((`"?Y0``C^`4T$OB,&B=Z'/T
M_^H(3@$`%$P!`!P!``!D30$`5`$``&Q%```\$)_E/#"?Y0$0C^`#,(_@`"#1
MY0``4N,>_R\1*""?Y0$`H.,``,'E`C"3YP``4^,>_R\!%`"?Y000@>(``(_@
M9?3_ZH1-`0"<2P$`6`$```A%```-P*#A-#*?Y?#8+>D$L$SB+&*?Y2#03>(H
M``OE!F"/X"P0"^4P(`OE*`!+X@-0EN<L$$OB,"!+X@`PE>4@,`OE,O3_Z_PA
MG^7\,9_E`B"6YP,`EN<"$*#A./3_Z^PQG^4#,);G`$#3Y0``5.-.```*W`&?
MY0``C^!X]/_K*'`;Y000A^(#<(?B!P%QXP`@D.5&,]+E`S"#XT8SPN57``"*
M`0&@X0WT_^NH(9_E+$`;Y0(@C^"@$9_E`1"/X``PH.$``)3E!#""Y9`AG^7P
M`,/A*``;Y0(0EN<!`%#C@"&?Y0`0D>4"((_@$`"@TPP@@^4($(/E"```V@00
MA.(,P(/B`$&$X`3@D>0$`%'A!."LY?O__QH#`(#B``&@X41!G^4`$*#C`!"-
MY0<@H.$`$(/G!$"/X#`1G^4,`)3E`1"/X!/T_^L``%#C*0``"AQ!G^4D8$OB
M!$"/X`P`E.7!\__K!A"@X0!PH.$$`9_E``"/X/#T_^L``%#C&```"O0PG^4#
M,(_@#`"3Y:?S_^ON\__K("`;Y0`PE>4'`*#A`P!2X2,``!H<T$OB\*B=Z+;S
M_^O$,)_E`S"/X```4.,,`(/E'```"HSS_^NP`)_E``"/X"+T_^L`,)#EYD7#
MY:/__^H(`)3E``!0XPD```IV^__KX?__Z@P`E.4`]/_KTO__ZGPPG^5\`)_E
M`Q"6YP``C^#$\__K<`"?Y080H.$``(_@Q/3_ZP``4.,(`(3ETO__"NW__^J.
M\__K`0"@XTKS_^M``0``.$L!`%`!``!@`0``+`$``!!,`0"P3`$`"`4``$P!
M``#@!```,$P!`"C<__\,3`$`_`$``.!+`0"L2P$`N$H!`$@!``#T`@``[```
M`'!S7W-T<FEN9W,@;6ES<VEN9PH`<&5R;'AS:2YC`````$-!0TA%```N````
M+BX``"5S+R5S````+W!R;V,O8W5R<')O8R]E>&4```!$>6YA3&]A9&5R.CIB
M;V]T7T1Y;F%,;V%D97(`26YT97)N86QS.CI005(Z.D)/3U0`````4$%27U1%
M35``````4$%27U!23T=.04U%`````#H````E<R5S)7,``%!%4DPU3$E"````
M`%!%4DQ,24(`4$523#5/4%0`````4$523$E/``!005)?24Y)5$E!3$E:140`
M4$%27U-005=.140`4$%27T-,14%.````4$%27T1%0E5'````4$%27T-!0TA%
M````4$%27T=,3T)!3%]$14)51P````!005)?1TQ/0D%,7U1-4$1)4@```%!!
M4E]435!$25(``%!!4E]'3$]"04Q?5$5-4`!005)?1TQ/0D%,7T-,14%.````
M`&QS965K(&9A:6QE9`````!R96%D(&9A:6QE9`!,1%],24)205)97U!!5$@`
M4UE35$5-```E,#)X`````"5S)7,E<R5S`````'!A<BT`````)7,Z(&-R96%T
M:6]N(&]F('!R:79A=&4@<W5B9&ER96-T;W)Y("5S(&9A:6QE9"`H97)R;F\]
M)6DI"@``)7,Z('!R:79A=&4@<W5B9&ER96-T;W)Y("5S(&ES('5N<V%F92`H
M<&QE87-E(')E;6]V92!I="!A;F0@<F5T<GD@>6]U<B!O<&5R871I;VXI"@``
M4$%42`````!P87)L`````"YP87(`````<VAO<G0@<F5A9```)7,E<V-A8VAE
M+25S)7,``"5S)7-T96UP+25U)7,````E<R5S=&5M<"TE=2TE=25S`````!@`
M``!P97)L`````#````!005(Z.E!A8VME<CHZ5D524TE/3@`````Q+C`V,0``
M`%5N86)L92!T;R!C<F5A=&4@8V%C:&4@9&ER96-T;W)Y`````"5S.B!C<F5A
M=&EO;B!O9B!P<FEV871E(&-A8VAE('-U8F1I<F5C=&]R>2`E<R!F86EL960@
M*&5R<FYO/25I*0H`````+64``"TM``!54T52`````%5315).04U%`````%1%
M35!$25(`5$U0`"]T;7`O````979A;"`G97AE8R`O=7-R+V)I;B]P97)L("`M
M4R`D,"`D>S$K(B1`(GTG"FEF(#`[(",@;F]T(')U;FYI;F<@=6YD97(@<V]M
M92!S:&5L;`IP86-K86=E(%]?<&%R7W!L.PIM>2`H)%!!4E]-04=)0RP@)$9)
M3$5?;V9F<V5T7W-I>F4L("1C86-H95]N86UE7W-I>F4I.PI"14=)3B!["B10
M05)?34%'24,@/2`B7&Y005(N<&U<;B(["B1&24Q%7V]F9G-E=%]S:7IE(#T@
M-#L@("`C('!A8VLH(DXB*0HD8V%C:&5?;F%M95]S:7IE(#T@-#`["B102UI)
M4%]-04=)0R`](")02UPP,#-<,#`T(CL*?0IS=6(@9FEN9%]P87)?;6%G:6,*
M>PIM>2`H)&9H*2`]($!?.PIM>2`D8VAU;FM?<VEZ92`](#8T("H@,3`R-#L*
M;7D@)&)U9CL*;7D@)'-I>F4@/2`M<R`D9F@["FUY("1P;W,@/2`H)'-I>F4M
M,2D@+2`H)'-I>F4M,2D@)2`D8VAU;FM?<VEZ93L@("`@("`C($Y/5$4Z("1P
M;W,@:7,@82!M=6QT:7!L92!O9B`D8VAU;FM?<VEZ90IW:&EL92`H)'!O<R`^
M/2`P*2!["G-E96L@)&9H+"`D<&]S+"`P.PIR96%D("1F:"P@)&)U9BP@)&-H
M=6YK7W-I>F4@*R!L96YG=&@H)%!!4E]-04=)0RD["FEF("@H;7D@)&D@/2!R
M:6YD97@H)&)U9BP@)%!!4E]-04=)0RDI(#X](#`I('L*<F5T=7)N("1P;W,@
M*R`D:3L*?0HD<&]S("T]("1C:'5N:U]S:7IE.PI]"G)E='5R;B`M,3L*?0IM
M>2`H)'!A<E]T96UP+"`D<')O9VYA;64L($!T;7!F:6QE+"`E36]D=6QE0V%C
M:&4I.PI%3D0@>R!I9B`H)$5.5GM005)?0TQ%04Y]*2!["G)E<75I<F4@1FEL
M93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*<F5Q=6ER92!&:6QE
M.CI3<&5C.PIM>2`D=&]P9&ER(#T@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H
M)'!A<E]T96UP*3L*;W5T<RAQ<5M296UO=FEN9R!F:6QE<R!I;B`B)'!A<E]T
M96UP(ETI.PI&:6QE.CI&:6YD.CIF:6YD9&5P=&@H<W5B('L@*"`M9"`I(#\@
M<FUD:7(@.B!U;FQI;FL@?2P@)'!A<E]T96UP*3L*<FUD:7(@)'!A<E]T96UP
M.PII9B`H+60@)'!A<E]T96UP("8F("1>3R!N92`G35-7:6XS,B<I('L*;7D@
M)'1M<"`](&YE=R!&:6QE.CI496UP*`I414U03$%412`]/B`G=&UP6%A86%@G
M+`I$25(@/3X@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H)'1O<&1I<BDL"E-5
M1D9)6"`]/B`G+F-M9"<L"E5.3$E.2R`]/B`P+`HI.PIM>2`D9FEL96YA;64@
M/2`D=&UP+3YF:6QE;F%M93L*<')I;G0@)'1M<"`\/"(N+BXB.PIX/3$[('=H
M:6QE(%L@7"1X("UL="`Q,"!=.R!D;PIR;2`M<F8@)R1P87)?=&5M<"<*:68@
M6R!<(2`M9"`G)'!A<E]T96UP)R!=.R!T:&5N"F)R96%K"F9I"G-L965P(#$*
M>#U@97AP<B!<)'@@*R`Q8`ID;VYE"G)M("<D9FEL96YA;64G"BXN+@IC;&]S
M92`D=&UP.PIC:&UO9"`P-S`P+"`D9FEL96YA;64["FUY("1C;60@/2`B)&9I
M;&5N86UE(#XO9&5V+VYU;&P@,CXF,2`F(CL*<WES=&5M*"1C;60I.PIO=71S
M*'%Q6U-P87=N960@8F%C:V=R;W5N9"!P<F]C97-S('1O('!E<F9O<FT@8VQE
M86YU<#H@)&9I;&5N86UE72D["GT*?2!]"D)%1TE.('L*26YT97)N86QS.CI0
M05(Z.D)/3U0H*2!I9B!D969I;F5D("9);G1E<FYA;',Z.E!!4CHZ0D]/5#L*
M979A;"!["E]P87)?:6YI=%]E;G8H*3L*;7D@)'%U:65T(#T@(21%3E9[4$%2
M7T1%0E5'?3L*;7D@)7-Y<R`]("@*<&%T:%]S97`@("`@/3X@*"1>3R`]?B`O
M7DU35VEN+R`_("<[)R`Z("<Z)RDL"E]E>&4@("`@("`@(#T^("@D7D\@/7X@
M+UXH/SI-4U=I;GQ/4S)\8WEG=VEN*2\@/R`G+F5X92<@.B`G)RDL"E]D96QI
M;2`@("`@(#T^("@D7D\@/7X@+UY-4U=I;GQ/4S(O(#\@)UQ<)R`Z("<O)RDL
M"BD["E]S971?<')O9VYA;64H*3L*;W5T<RAQ<5M<)'!R;V=N86UE(#T@(B1P
M<F]G;F%M92)=*3L*7W-E=%]P87)?=&5M<"@I.PIO=71S*'%Q6UPD14Y6>U!!
M4E]414U0?2`]("(D14Y6>U!!4E]414U0?2)=*3L*;7D@*"1S=&%R=%]P;W,L
M("1S=&%R=%]O9E]&24Q%7W-E8W1I;VXI.PI-04=)0SH@>PIL;V-A;"`D4TE'
M>U]?5T%23E]??2`]('-U8B![?3L*=6YL97-S("AO<&5N(%]&2"P@)SPZ<F%W
M)RP@)'!R;V=N86UE*2!["F]U=',H<7%;0V%N)W0@<F5A9"!F<F]M(&9I;&4@
M(B1P<F]G;F%M92)=*3L@(",@9&]N)W0@=7-E("0A(&AE<F4@87,@:70@<F5Q
M=6ER97,@17)R;F\N<&T*;&%S="!-04=)0SL*?0IM>2`D;6%G:6-?<&]S(#T@
M9FEN9%]P87)?;6%G:6,H*E]&2"D["FEF("@D;6%G:6-?<&]S(#P@,"D@>PIO
M=71S*'%Q6T-A;B=T(&9I;F0@;6%G:6,@<W1R:6YG("(D4$%27TU!1TE#(B!I
M;B!F:6QE("(D<')O9VYA;64B72D["FQA<W0@34%'24,["GT*;W5T<R@B1F]U
M;F0@4$%2(&UA9VEC(&%T('!O<VET:6]N("1M86=I8U]P;W,B*3L*<V5E:R!?
M1D@L("1M86=I8U]P;W,@+2`D1DE,15]O9F9S971?<VEZ92`M(&QE;F=T:"@B
M7#!#04-(12(I+"`P.PIR96%D(%]&2"P@)&)U9BP@;&5N9W1H*")<,$-!0TA%
M(BD["FEF("@D8G5F(&YE(")<,$-!0TA%(B`F)B`D8G5F(&YE(")<,$-,14%.
M(BD@>PIO=71S*").;R!C86-H92!M87)K97(@9F]U;F0B*3L*;&%S="!-04=)
M0SL*?0IO=71S*'%Q6T-A8VAE(&UA<FME<B`B)&)U9B(@9F]U;F1=*3L*<V5E
M:R!?1D@L("1M86=I8U]P;W,@+2`D1DE,15]O9F9S971?<VEZ92P@,#L*<F5A
M9"!?1D@L("1B=68L("1&24Q%7V]F9G-E=%]S:7IE.PIM>2`D;V9F<V5T(#T@
M=6YP86-K*").(BP@)&)U9BD["F]U=',H(D]F9G-E="!F<F]M('-T87)T(&]F
M($9)3$5S(&ES("1O9F9S970B*3L*<V5E:R!?1D@L("1M86=I8U]P;W,@+2`D
M1DE,15]O9F9S971?<VEZ92`M("1O9F9S970L(#`["B1S=&%R=%]O9E]&24Q%
M7W-E8W1I;VX@/2!T96QL(%]&2#L*;7D@)7)E<75I<F5?;&ES=#L*<F5A9"!?
M1D@L("1B=68L(#0[("`@("`@("`@("`@("`@("`@("`@("`@("`@(R!R96%D
M('1H92!F:7)S="`B1DE,12(*=VAI;&4@*"1B=68@97$@(D9)3$4B*2!["G)E
M860@7T9(+"`D8G5F+"`T.PIR96%D(%]&2"P@)&)U9BP@=6YP86-K*").(BP@
M)&)U9BD["FUY("1F=6QL;F%M92`]("1B=68["F]U=',H<7%;56YP86-K:6YG
M($9)3$4@(B1F=6QL;F%M92(N+BY=*3L*;7D@)&-R8R`]("@@)&9U;&QN86UE
M(#U^('-\7BA;82UF7&1=>SA]*2]\?"`I(#\@)#$@.B!U;F1E9CL*;7D@*"1B
M87-E;F%M92P@)&5X="D@/2`H)&)U9B`]?B!M?"@_.BXJ+RD_*"XJ*2A<+BXJ
M*7PI.PIR96%D(%]&2"P@)&)U9BP@-#L*<F5A9"!?1D@L("1B=68L('5N<&%C
M:R@B3B(L("1B=68I.PII9B`H9&5F:6YE9"@D97AT*2!A;F0@)&5X="`A?B`O
M7"XH/SIP;7QP;'QI>'QA;"DD+VDI('L*;7D@)&9I;&5N86UE(#T@7W-A=F5?
M87,H(B1C<F,D97AT(BP@)&)U9BP@,#<U-2D["B1005(Z.DAE879Y.CI&=6QL
M0V%C:&5[)&9U;&QN86UE?2`]("1F:6QE;F%M93L*)%!!4CHZ2&5A=GDZ.D9U
M;&Q#86-H97LD9FEL96YA;65](#T@)&9U;&QN86UE.PI]"F5L<V4@>PHD36]D
M=6QE0V%C:&5[)&9U;&QN86UE?2`]('L*8G5F(#T^("1B=68L"F-R8R`]/B`D
M8W)C+`IN86UE(#T^("1F=6QL;F%M92P*?3L*)')E<75I<F5?;&ES='LD9G5L
M;&YA;65]*RL["GT*<F5A9"!?1D@L("1B=68L(#0["GT*;&]C86P@0$E.0R`]
M("AS=6(@>PIM>2`H)'-E;&8L("1M;V1U;&4I(#T@0%\["G)E='5R;B!I9B!R
M968@)&UO9'5L92!O<B`A)&UO9'5L93L*;7D@)&EN9F\@/2`D36]D=6QE0V%C
M:&5[)&UO9'5L97T["G)E='5R;B!U;FQE<W,@)&EN9F\["F1E;&5T92`D<F5Q
M=6ER95]L:7-T>R1M;V1U;&5].PHD24Y#>R1M;V1U;&5](#T@(B]L;V%D97(O
M)&EN9F\O)&UO9'5L92(["FEF("@D14Y6>U!!4E]#3$5!3GT@86YD(&1E9FEN
M960H)DE/.CI&:6QE.CIN97<I*2!["FUY("1F:"`]($E/.CI&:6QE+3YN97=?
M=&UP9FEL92!O<B!D:64@(D-A;B=T(&-R96%T92!T96UP(&9I;&4Z("0A(CL*
M)&9H+3YB:6YM;V1E*"D["B1F:"T^<')I;G0H)&EN9F\M/GMB=69]*3L*)&9H
M+3YS965K*#`L(#`I.PIR971U<FX@)&9H.PI]"F5L<V4@>PIM>2`D9FEL96YA
M;64@/2!?<V%V95]A<R@B)&EN9F\M/GMC<F-]+G!M(BP@)&EN9F\M/GMB=69]
M*3L*)&EN9F\M/GMF:6QE?2`]("1F:6QE;F%M93L*;W!E;B!M>2`D9F@L("<\
M.G)A=R<L("1F:6QE;F%M92!O<B!D:64@<7%;0V%N)W0@<F5A9"`B)&9I;&5N
M86UE(CH@)"%=.PIR971U<FX@)&9H.PI]"F1I92`B0F]O='-T<F%P<&EN9R!F
M86EL960Z(&-A;B=T(&9I;F0@;6]D=6QE("1M;V1U;&4A(CL*?2P@0$E.0RD[
M"G)E<75I<F4@6%-,;V%D97(["G)E<75I<F4@4$%2.CI(96%V>3L*<F5Q=6ER
M92!#87)P.CI(96%V>3L*<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD["E!!4CHZ
M2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*<F5Q=6ER92!)3SHZ1FEL93L*
M=VAI;&4@*&UY("1F:6QE;F%M92`]("AS;W)T(&ME>7,@)7)E<75I<F5?;&ES
M="E;,%TI('L*=6YL97-S("@D24Y#>R1F:6QE;F%M97T@;W(@)&9I;&5N86UE
M(#U^("]"4T1004XO*2!["FEF("@D9FEL96YA;64@/7X@+UPN<&UC/R0O:2D@
M>PIR97%U:7)E("1F:6QE;F%M93L*?0IE;'-E('L*9&\@)&9I;&5N86UE('5N
M;&5S<R`D9FEL96YA;64@/7X@+W-I=&5C=7-T;VUI>F5<+G!L)"\["GT*?0ID
M96QE=&4@)')E<75I<F5?;&ES='LD9FEL96YA;65].PI]"FEF("@D8G5F(&YE
M("102UI)4%]-04=)0RD@>PIO=71S*'%Q6TYO('II<"!F;W5N9"!A9G1E<B!&
M24Q%('-E8W1I;VX@:6X@9FEL92`B)'!R;V=N86UE(ETI.PIL87-T($U!1TE#
M(#L*?0HD<W1A<G1?<&]S(#T@*'1E;&P@7T9(*2`M(#0[("`@("`@("`@("`@
M("`@(",@<W1A<G0@;V8@>FEP"GT*;7D@0'!A<E]A<F=S.PIM>2`H)&]U="P@
M)&)U;F1L92P@)&QO9V9H+"`D8V%C:&5?;F%M92D["F1E;&5T92`D14Y6>U!!
M4E]!4%!?4D554T5].R`C('-A;FET:7IE("A2155312!M87D@8F4@82!S96-U
M<FET>2!P<F]B;&5M*0II9B`H(21S=&%R=%]P;W,@;W(@*"1!4D=66S!=(&5Q
M("<M+7!A<BUO<'1I;VYS)R`F)B!S:&EF="DI('L*;7D@)61I<W1?8VUD(#T@
M<7<H"G`@("!B;&EB7W1O7W!A<@II("`@:6YS=&%L;%]P87(*=2`@('5N:6YS
M=&%L;%]P87(*<R`@('-I9VY?<&%R"G8@("!V97)I9GE?<&%R"BD["FEF("A`
M05)'5B!A;F0@)$%21U9;,%T@97$@)RTM<F5U<V4G*2!["G-H:69T($!!4D=6
M.PHD14Y6>U!!4E]!4%!?4D554T5](#T@<VAI9G0@0$%21U8["GT*96QS92![
M(",@;F]R;6%L('!A<FP@8F5H879I;W5R"FUY($!A9&1?=&]?:6YC.PIW:&EL
M92`H0$%21U8I('L*)$%21U9;,%T@/7X@+UXM*%M!24U/0DQB<7!I=7-4=ETI
M*"XJ*2\@;W(@;&%S=#L*:68@*"0Q(&5Q("=))RD@>PIP=7-H($!A9&1?=&]?
M:6YC+"`D,CL*?0IE;'-I9B`H)#$@97$@)TTG*2!["F5V86P@(G5S92`D,B([
M"GT*96QS:68@*"0Q(&5Q("=!)RD@>PIU;G-H:69T($!P87)?87)G<RP@)#([
M"GT*96QS:68@*"0Q(&5Q("=/)RD@>PHD;W5T(#T@)#(["GT*96QS:68@*"0Q
M(&5Q("=B)RD@>PHD8G5N9&QE(#T@)W-I=&4G.PI]"F5L<VEF("@D,2!E<2`G
M0B<I('L*)&)U;F1L92`]("=A;&PG.PI]"F5L<VEF("@D,2!E<2`G<2<I('L*
M)'%U:65T(#T@,3L*?0IE;'-I9B`H)#$@97$@)TPG*2!["F]P96X@)&QO9V9H
M+"`B/CXB+"`D,B!O<B!D:64@<7%;0V%N)W0@;W!E;B!L;V<@9FEL92`B)#(B
M.B`D(5T["GT*96QS:68@*"0Q(&5Q("=4)RD@>PHD8V%C:&5?;F%M92`]("0R
M.PI]"G-H:69T*$!!4D=6*3L*:68@*&UY("1C;60@/2`D9&ES=%]C;61[)#%]
M*2!["F1E;&5T92`D14Y6>R=005)?5$5-4"=].PII;FET7VEN8R@I.PIR97%U
M:7)E(%!!4CHZ1&ES=#L*)GLB4$%2.CI$:7-T.CHD8VUD(GTH*2!U;FQE<W,@
M0$%21U8["B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"1?*2!F;W(@0$%21U8["F5X
M:70["GT*?0IU;G-H:69T($!)3D,L($!A9&1?=&]?:6YC.PI]"GT*:68@*"1O
M=70I('L*>PIR97%U:7)E($E/.CI&:6QE.PIR97%U:7)E($%R8VAI=F4Z.EII
M<#L*<F5Q=6ER92!$:6=E<W0Z.E-(03L*?0IM>2`D<&%R(#T@<VAI9G0H0$%2
M1U8I.PIM>2`D>FEP.PII9B`H9&5F:6YE9"`D<&%R*2!["F]P96X@;7D@)&9H
M+"`G/#IR87<G+"`D<&%R(&]R(&1I92!Q<5M#86XG="!F:6YD('!A<B!F:6QE
M("(D<&%R(CH@)"%=.PIB;&5S<R@D9F@L("=)3SHZ1FEL92<I.PHD>FEP(#T@
M07)C:&EV93HZ6FEP+3YN97<["B@@)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE
M*"1F:"P@)'!A<BD@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I("D*;W(@9&EE
M('%Q6T5R<F]R(')E861I;F<@>FEP(&%R8VAI=F4@(B1P87(B73L*?0IM>2`E
M;65T85]P87(@/2!D;R!["FEF("@D>FEP(&%N9"!M>2`D;65T82`]("1Z:7`M
M/F-O;G1E;G1S*"=-151!+GEM;"<I*2!["B1M971A(#U^(',O+BI><&%R.B0O
M+VUS.PHD;65T82`]?B!S+UY<4RXJ+R]M<SL*)&UE=&$@/7X@+UX@("A;7CI=
M*RDZ("@N*RDD+VUG.PI]"GT["FEF("AD969I;F5D("1P87(I('L*;W!E;B!M
M>2`D<&@L("<\.G)A=R<L("1P87(@;W(@9&EE('%Q6T-A;B=T(')E860@<&%R
M(&9I;&4@(B1P87(B.B`D(5T["FUY("1B=68["G)E860@)'!H+"`D8G5F+"`T
M.PID:64@<7%;(B1P87(B(&ES(&YO="!A('!A<B!F:6QE72!U;FQE<W,@)&)U
M9B!E<2`D4$M:25!?34%'24,["F-L;W-E("1P:#L*?0I#<F5A=&50871H*"1O
M=70I(#L*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=R@*)&]U="P*24\Z.D9I;&4Z
M.D]?0U)%050H*2!\($E/.CI&:6QE.CI/7U)$5U(H*2!\($E/.CI&:6QE.CI/
M7U1254Y#*"DL"C`W-S<L"BD@;W(@9&EE('%Q6T-A;B=T(&-R96%T92!F:6QE
M("(D;W5T(CH@)"%=.PHD9F@M/F)I;FUO9&4H*3L*<V5E:R!?1D@L(#`L(#`[
M"FUY("1L;V%D97(["FEF("AD969I;F5D("1S=&%R=%]O9E]&24Q%7W-E8W1I
M;VXI('L*<F5A9"!?1D@L("1L;V%D97(L("1S=&%R=%]O9E]&24Q%7W-E8W1I
M;VX["GT@96QS92!["FQO8V%L("0O(#T@=6YD968["B1L;V%D97(@/2`\7T9(
M/CL*?0II9B`H(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@)&QO861E<B`]?B`O
M7B@_.B,A?%Q`<F5M*2\I('L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R
M:7`["E!!4CHZ1FEL=&5R.CI0;V13=')I<"T^87!P;'DH7"1L;V%D97(L("0P
M*3L*?0HD9F@M/G!R:6YT*"1L;V%D97(I"F]R(&1I92!Q<5M%<G)O<B!W<FET
M:6YG(&QO861E<B!T;R`B)&]U="(Z("0A73L*:68@*"1B=6YD;&4I('L*<F5Q
M=6ER92!005(Z.DAE879Y.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R
M*"D["FEN:71?:6YC*"D["G)E<75I<F5?;6]D=6QE<R@I.PIM>2!`:6YC(#T@
M9W)E<"![("$O0E-$4$%.+R!]"F=R97`@>PHH)&)U;F1L92!N92`G<VET92<I
M(&]R"B@D7R!N92`D0V]N9FEG.CI#;VYF:6=[87)C:&QI8F5X<'T@86YD"B1?
M(&YE("1#;VYF:6<Z.D-O;F9I9WMP<FEV;&EB97AP?2D["GT@0$E.0SL*<WPO
M*WPO?&<L('-\+R1\?"!F;W)E86-H($!I;F,["FUY("5F:6QE<SL*)&9I;&5S
M>R1??2LK(&9O<B!`1'EN84QO861E<CHZ9&Q?<VAA<F5D7V]B:F5C=',L('9A
M;'5E<R`E24Y#.PIM>2`D;&EB7V5X="`]("1#;VYF:6<Z.D-O;F9I9WML:6)?
M97AT?3L@("`@("`@("`C(%A86"!L:6)?97AT('9S(&1L97AT(#\*;7D@)7=R
M:71T96X["F9O<F5A8V@@;7D@)&ME>2`H<V]R="!K97ES("5F:6QE<RD@>PIM
M>2`H)&9I;&4L("1N86UE*3L*:68@*&1E9FEN960H;7D@)&9C(#T@)%!!4CHZ
M2&5A=GDZ.D9U;&Q#86-H97LD:V5Y?2DI('L**"1F:6QE+"`D;F%M92D@/2`H
M)&ME>2P@)&9C*3L*?0IE;'-E('L*9F]R96%C:"!M>2`D9&ER("A`:6YC*2![
M"FEF("@D:V5Y(#U^(&U\7EQ1)&1I<EQ%+R@N*BDD?&DI('L**"1F:6QE+"`D
M;F%M92D@/2`H)&ME>2P@)#$I.PIL87-T.PI]"FEF("@D:V5Y(#U^(&U\7B]L
M;V%D97(O6UXO72LO*"XJ*21\*2!["FEF("AM>2`D<F5F(#T@)$UO9'5L94-A
M8VAE>R0Q?2D@>PHH)&9I;&4L("1N86UE*2`]("@D<F5F+"`D,2D["FQA<W0[
M"GT*:68@*"UF("(D9&ER+R0Q(BD@>PHH)&9I;&4L("1N86UE*2`]("@B)&1I
M<B\D,2(L("0Q*3L*;&%S=#L*?0I]"GT*?0IN97AT('5N;&5S<R!D969I;F5D
M("1N86UE.PIN97AT(&EF("1W<FET=&5N>R1N86UE?2LK.PIN97AT(&EF("%R
M968H)&9I;&4I(&%N9"`D9FEL92`]?B`O7"Y<421L:6)?97AT7$4D+VD["F]U
M=',H<W!R:6YT9BAQ<5M086-K:6YG($9)3$4@(B5S(BXN+ETL(')E9B`D9FEL
M92`_("1F:6QE+3Y[;F%M97T@.B`D9FEL92DI.PIM>2`D8V]N=&5N=#L*:68@
M*')E9B@D9FEL92DI('L*)&-O;G1E;G0@/2`D9FEL92T^>V)U9GT["GT*96QS
M92!["FQO8V%L("0O(#T@=6YD968["F]P96X@;7D@)'1H+"`G/#IR87<G+"`D
M9FEL92!O<B!D:64@<7%;0V%N)W0@<F5A9"`B)&9I;&4B.B`D(5T["B1C;VYT
M96YT(#T@/"1T:#X["F-L;W-E("1T:#L*4$%2.CI&:6QT97(Z.E!O9%-T<FEP
M+3YA<'!L>2A<)&-O;G1E;G0L("(\96UB961D960^+R1N86UE(BD*:68@(21%
M3E9[4$%27U9%4D)!5$E-?2!A;F0@)&YA;64@/7X@+UPN*#\Z<&U\:7A\86PI
M)"]I.PI005(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT+3YN97<M/F%P<&QY*%PD
M8V]N=&5N="P@)&9I;&4L("1N86UE*3L*?0HD9F@M/G!R:6YT*")&24Q%(BP*
M<&%C:R@G3B<L(&QE;F=T:"@D;F%M92D@*R`Y*2P*<W!R:6YT9B@B)3`X>"\E
M<R(L($%R8VAI=F4Z.EII<#HZ8V]M<'5T94-20S,R*"1C;VYT96YT*2P@)&YA
M;64I+`IP86-K*"=.)RP@;&5N9W1H*"1C;VYT96YT*2DL"B1C;VYT96YT*0IO
M<B!D:64@<7%;17)R;W(@=W)I=&EN9R!E;6)E9&1E9"!&24Q%('1O("(D;W5T
M(CH@)"%=.PIO=71S*'%Q6U=R:71T96X@87,@(B1N86UE(ETI.PI]"GT*:68@
M*"1Z:7`I('L*)'II<"T^=W)I=&54;T9I;&5(86YD;&4H)&9H*2`]/2!!<F-H
M:79E.CI::7`Z.D%:7T]+"F]R(&1I92!Q<5M%<G)O<B!W<FET:6YG('II<"!P
M87)T(&]F("(D;W5T(ET["GT*:68@*"1M971A7W!A<GMC;&5A;GTI('L*)&9H
M+3YP<FEN="@B7#!#3$5!3B(I.PI]"F5L<V4@>PII9B`H(61E9FEN960@)&-A
M8VAE7VYA;64I('L*;7D@)&-T>"`]($1I9V5S=#HZ4TA!+3YN97<H,2D["G-E
M96L@)&9H+"`P+"`P.PHD8W1X+3YA9&1F:6QE*"1F:"D["G-E96L@)&9H+"`P
M+"`R.PHD8V%C:&5?;F%M92`]("1C='@M/FAE>&1I9V5S=#L*?0HD8V%C:&5?
M;F%M92`]('-U8G-T<B`D8V%C:&5?;F%M92P@,"P@)&-A8VAE7VYA;65?<VEZ
M93L*)&-A8VAE7VYA;64@+CT@(EPP(B!X("@D8V%C:&5?;F%M95]S:7IE("T@
M;&5N9W1H("1C86-H95]N86UE*3L*)&9H+3YP<FEN="@D8V%C:&5?;F%M92P*
M(EPP0T%#2$4B*3L*?0IM>2`D;V9F<V5T(#T@)&9H+3YT96QL("T@;&5N9W1H
M*"1L;V%D97(I.PHD9F@M/G!R:6YT*'!A8VLH)TXG+"`D;V9F<V5T*2P*)%!!
M4E]-04=)0RD["B1F:"T^8VQO<V4@;W(@9&EE('%Q6T5R<F]R('=R:71I;F<@
M=')A:6QE<B!O9B`B)&]U="(Z("0A73L*8VAM;V0@,#<U-2P@)&]U=#L*97AI
M=#L*?0I["FQA<W0@=6YL97-S(&1E9FEN960@)'-T87)T7W!O<SL*7V9I>%]P
M<F]G;F%M92@I.PIR97%U:7)E(%!!4CL*4$%2.CI(96%V>3HZ7VEN:71?9'EN
M86QO861E<B@I.PI["G)E<75I<F4@1FEL93HZ1FEN9#L*<F5Q=6ER92!!<F-H
M:79E.CI::7`["GT*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=SL@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(",@07)C:&EV93HZ6FEP(&]P97)A=&5S(&]N
M(&%N($E/.CI(86YD;&4*)&9H+3YF9&]P96XH9FEL96YO*%]&2"DL("=R)RD@
M;W(@9&EE('%Q6V9D;W!E;B@I(&9A:6QE9#H@)"%=.PI!<F-H:79E.CI::7`Z
M.G-E=$-H=6YK4VEZ92@M<R!?1D@I.PIM>2`D>FEP(#T@07)C:&EV93HZ6FEP
M+3YN97<["B@D>FEP+3YR96%D1G)O;49I;&5(86YD;&4H)&9H+"`D<')O9VYA
M;64I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2D*;W(@9&EE('%Q6T5R<F]R
M(')E861I;F<@>FEP(&%R8VAI=F4@(B1P<F]G;F%M92)=.PI!<F-H:79E.CI:
M:7`Z.G-E=$-H=6YK4VEZ92@V-"`J(#$P,C0I.PIP=7-H($!005(Z.DQI8D-A
M8VAE+"`D>FEP.PHD4$%2.CI,:6)#86-H97LD<')O9VYA;65](#T@)'II<#L*
M;W5T<R@B17AT<F%C=&EN9R!Z:7`N+BXB*3L*:68@*&1E9FEN960@)$5.5GM0
M05)?5$5-4'TI('L@(R!S:&]U;&0@8F4@<V5T(&%T('1H:7,@<&]I;G0A"F9O
M<F5A8V@@;7D@)&UE;6)E<B`H("1Z:7`M/FUE;6)E<G,@*2!["FYE>'0@:68@
M)&UE;6)E<BT^:7-$:7)E8W1O<GD["FUY("1M96UB97)?;F%M92`]("1M96UB
M97(M/F9I;&5.86UE.PIN97AT('5N;&5S<R`D;65M8F5R7VYA;64@/7X@;7L*
M7@HO/W-H;&EB+PHH/SHD0V]N9FEG.CI#;VYF:6=[87)C:&YA;65]+RD_"BA;
M7B]=*RD*)`I]>#L*;7D@)&5X=')A8W1?;F%M92`]("0Q.PIM>2`D9&5S=%]N
M86UE(#T@1FEL93HZ4W!E8RT^8V%T9FEL92@D14Y6>U!!4E]414U0?2P@)&5X
M=')A8W1?;F%M92D["FEF("@M9B`D9&5S=%]N86UE("8F("US(%\@/3T@)&UE
M;6)E<BT^=6YC;VUP<F5S<V5D4VEZ92@I*2!["F]U=',H<7%;4VMI<'!I;F<@
M(B1M96UB97)?;F%M92(@<VEN8V4@:70@86QR96%D>2!E>&ES=',@870@(B1D
M97-T7VYA;64B72D["GT@96QS92!["F]U=',H<7%;17AT<F%C=&EN9R`B)&UE
M;6)E<E]N86UE(B!T;R`B)&1E<W1?;F%M92(N+BY=*3L**"1M96UB97(M/F5X
M=')A8W14;T9I;&5.86UE9"@D9&5S=%]N86UE*2`]/2!!<F-H:79E.CI::7`Z
M.D%:7T]+*"DI"F]R(&1I92!Q<5M%<G)O<B!E>'1R86-T:6YG('II<"!M96UB
M97(@=&\@(B1D97-T7VYA;64B73L*8VAM;V0H,#4U-2P@)&1E<W1?;F%M92D@
M:68@)%Y/(&5Q(")H<'5X(CL*?0I]"GT*?0IU;FQE<W,@*"1005(Z.DQI8D-A
M8VAE>R1P<F]G;F%M97TI('L*9&EE(#P\("(N(B!U;FQE<W,@0$%21U8["E5S
M86=E.B`D,"!;("U!;&EB+G!A<B!=(%L@+4ED:7(@72!;("U-;6]D=6QE(%T@
M6R!S<F,N<&%R(%T@6R!P<F]G<F%M+G!L(%T*)#`@6R`M0GPM8B!=(%LM3V]U
M=&9I;&5=('-R8RYP87(*+@HD14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA
M;64@/2`D,"`]('-H:69T*$!!4D=6*3L*?0IS=6(@0W)E871E4&%T:"!["FUY
M("@D;F%M92D@/2!`7SL*<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*;7D@*"1B
M87-E;F%M92P@)'!A=&@L("1E>'0I(#T@1FEL93HZ0F%S96YA;64Z.F9I;&5P
M87)S92@D;F%M92P@*"=<+BXJ)RDI.PIR97%U:7)E($9I;&4Z.E!A=&@["D9I
M;&4Z.E!A=&@Z.FUK<&%T:"@D<&%T:"D@=6YL97-S*"UE("1P871H*3L@(R!M
M:W!A=&@@9&EE<R!W:71H(&5R<F]R"GT*<W5B(')E<75I<F5?;6]D=6QE<R![
M"G)E<75I<F4@;&EB.PIR97%U:7)E($1Y;F%,;V%D97(["G)E<75I<F4@:6YT
M96=E<CL*<F5Q=6ER92!S=')I8W0["G)E<75I<F4@=V%R;FEN9W,["G)E<75I
M<F4@=F%R<SL*<F5Q=6ER92!#87)P.PIR97%U:7)E($-A<G`Z.DAE879Y.PIR
M97%U:7)E($5R<FYO.PIR97%U:7)E($5X<&]R=&5R.CI(96%V>3L*<F5Q=6ER
M92!%>'!O<G1E<CL*<F5Q=6ER92!&8VYT;#L*<F5Q=6ER92!&:6QE.CI496UP
M.PIR97%U:7)E($9I;&4Z.E-P96,["G)E<75I<F4@6%-,;V%D97(["G)E<75I
M<F4@0V]N9FEG.PIR97%U:7)E($E/.CI(86YD;&4["G)E<75I<F4@24\Z.D9I
M;&4["G)E<75I<F4@0V]M<')E<W,Z.EIL:6(["G)E<75I<F4@07)C:&EV93HZ
M6FEP.PIR97%U:7)E($1I9V5S=#HZ4TA!.PIR97%U:7)E(%!!4CL*<F5Q=6ER
M92!005(Z.DAE879Y.PIR97%U:7)E(%!!4CHZ1&ES=#L*<F5Q=6ER92!005(Z
M.D9I;'1E<CHZ4&]D4W1R:7`["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!A=&-H
M0V]N=&5N=#L*<F5Q=6ER92!A='1R:6)U=&5S.PIE=F%L('L@<F5Q=6ER92!#
M=V0@?3L*979A;"![(')E<75I<F4@5VEN,S(@?3L*979A;"![(')E<75I<F4@
M4V-A;&%R.CI5=&EL('T["F5V86P@>R!R97%U:7)E($%R8VAI=F4Z.E5N>FEP
M.CI"=7)S="!].PIE=F%L('L@<F5Q=6ER92!4:64Z.DAA<V@Z.DYA;65D0V%P
M='5R92!].PIE=F%L('L@<F5Q=6ER92!097)L24\[(')E<75I<F4@4&5R;$E/
M.CIS8V%L87(@?3L*979A;"![(')E<75I<F4@=71F."!].PI]"G-U8B!?<V5T
M7W!A<E]T96UP('L*:68@*&1E9FEN960@)$5.5GM005)?5$5-4'T@86YD("1%
M3E9[4$%27U1%35!](#U^("\H+BLI+RD@>PHD<&%R7W1E;7`@/2`D,3L*<F5T
M=7)N.PI]"F9O<F5A8V@@;7D@)'!A=&@@*`HH;6%P("1%3E9[)%]]+"!Q=R@@
M4$%27U1-4$1)4B!435!$25(@5$5-4$1)4B!414U0(%1-4"`I*2P*<7<H($,Z
M7%Q414U0("]T;7`@+B`I"BD@>PIN97AT('5N;&5S<R!D969I;F5D("1P871H
M(&%N9"`M9"`D<&%T:"!A;F0@+7<@)'!A=&@["FUY("1U<V5R;F%M93L*;7D@
M)'!W=6ED.PIE=F%L('LH)'!W=6ED*2`](&=E='!W=6ED*"0^*2!I9B!D969I
M;F5D("0^.WT["FEF("@@9&5F:6YE9"@F5VEN,S(Z.DQO9VEN3F%M92D@*2![
M"B1U<V5R;F%M92`]("97:6XS,CHZ3&]G:6Y.86UE.PI]"F5L<VEF("AD969I
M;F5D("1P=W5I9"D@>PHD=7-E<FYA;64@/2`D<'=U:60["GT*96QS92!["B1U
M<V5R;F%M92`]("1%3E9[55-%4DY!345]('Q\("1%3E9[55-%4GT@?'P@)U-9
M4U1%32<["GT*;7D@)'-T;7!D:7(@/2`B)'!A=&@D<WES>U]D96QI;7UP87(M
M(BYU;G!A8VLH(D@J(BP@)'5S97)N86UE*3L*;6MD:7(@)'-T;7!D:7(L(#`W
M-34["FUY("1C86-H95]D:7(["FEF("@D14Y6>U!!4E]#3$5!3GTI('L*)&-A
M8VAE7V1I<B`](")T96UP+20D(CL*?0IE;'-E('L*;W!E;B!M>2`D9F@L("(\
M.G)A=R(L("1P<F]G;F%M92!O<B!D:64@<7%;0V%N)W0@<F5A9"`B)'!R;V=N
M86UE(CH@)"%=.PII9B`H*&UY("1M86=I8U]P;W,@/2!F:6YD7W!A<E]M86=I
M8R@D9F@I*2`^/2`P*2!["G-E96L@)&9H+"`D;6%G:6-?<&]S"BT@)$9)3$5?
M;V9F<V5T7W-I>F4*+2!L96YG=&@H(EPP0T%#2$4B*2P@,#L*;7D@)&)U9CL*
M<F5A9"`D9F@L("1B=68L(&QE;F=T:"@B7#!#04-(12(I.PII9B`H)&)U9B!E
M<2`B7#!#04-(12(I('L*<V5E:R`D9F@L("1M86=I8U]P;W,*+2`D1DE,15]O
M9F9S971?<VEZ90HM(&QE;F=T:"@B7#!#04-(12(I"BT@)&-A8VAE7VYA;65?
M<VEZ92P@,#L*<F5A9"`D9F@L("1B=68L("1C86-H95]N86UE7W-I>F4["B1B
M=68@/7X@<R]<,"\O9SL*)&-A8VAE7V1I<B`](")C86-H92TD8G5F(CL*?0I]
M"F-L;W-E("1F:#L*?0II9B`H(21C86-H95]D:7(I('L*)&-A8VAE7V1I<B`]
M(")T96UP+20D(CL*)$5.5GM005)?0TQ%04Y](#T@,3L*?0HD<W1M<&1I<B`N
M/2`B)'-Y<WM?9&5L:6U])&-A8VAE7V1I<B(["FUK9&ER("1S=&UP9&ER+"`P
M-S4U.PHD14Y6>U!!4E]414U0?2`]("1S=&UP9&ER.PIL87-T.PI]"B1P87)?
M=&5M<"`]("0Q(&EF("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0
M?2`]?B`O*"XK*2\["GT*<W5B(%]S879E7V%S('L*;7D@*"1N86UE+"`D8V]N
M=&5N=',L("1M;V1E*2`]($!?.PIM>2`D9G5L;&YA;64@/2`B)'!A<E]T96UP
M+R1N86UE(CL*=6YL97-S("@M92`D9G5L;&YA;64I('L*;7D@)'1E;7!N86UE
M(#T@(B1F=6QL;F%M92XD)"(["FUY("1F:#L**&]P96X@)&9H+"`G/CIR87<G
M+"`D=&5M<&YA;64I"B8F("AP<FEN="`D9F@@)&-O;G1E;G1S*0HF)B`H8VQO
M<V4@)&9H*0IO<B!D:64@<7%;17)R;W(@=W)I=&EN9R`B)'1E;7!N86UE(CH@
M)"%=.PIC:&UO9"`D;6]D92P@)'1E;7!N86UE(&EF(&1E9FEN960@)&UO9&4[
M"G)E;F%M92@D=&5M<&YA;64L("1F=6QL;F%M92D@;W(@=6YL:6YK*"1T96UP
M;F%M92D["GT*<F5T=7)N("1F=6QL;F%M93L*?0IS=6(@7W-E=%]P<F]G;F%M
M92!["FEF("AD969I;F5D("1%3E9[4$%27U!23T=.04U%?2!A;F0@)$5.5GM0
M05)?4%)/1TY!345](#U^("\H+BLI+RD@>PHD<')O9VYA;64@/2`D,3L*?0HD
M<')O9VYA;64@?'P]("0P.PII9B`H)$5.5GM005)?5$5-4'T@86YD(&EN9&5X
M*"1P<F]G;F%M92P@)$5.5GM005)?5$5-4'TI(#X](#`I('L*)'!R;V=N86UE
M(#T@<W5B<W1R*"1P<F]G;F%M92P@<FEN9&5X*"1P<F]G;F%M92P@)'-Y<WM?
M9&5L:6U]*2`K(#$I.PI]"FEF("@A)$5.5GM005)?4%)/1TY!345](&]R(&EN
M9&5X*"1P<F]G;F%M92P@)'-Y<WM?9&5L:6U]*2`^/2`P*2!["FEF("AO<&5N
M(&UY("1F:"P@)SPG+"`D<')O9VYA;64I('L*<F5T=7)N(&EF("US("1F:#L*
M?0II9B`H+7,@(B1P<F]G;F%M921S>7-[7V5X97TB*2!["B1P<F]G;F%M92`N
M/2`D<WES>U]E>&5].PIR971U<FX["GT*?0IF;W)E86-H(&UY("1D:7(@*'-P
M;&ET("]<421S>7-[<&%T:%]S97!]7$4O+"`D14Y6>U!!5$A]*2!["FYE>'0@
M:68@97AI<W1S("1%3E9[4$%27U1%35!](&%N9"`D9&ER(&5Q("1%3E9[4$%2
M7U1%35!].PHD9&ER(#U^(',O7%$D<WES>U]D96QI;7U<120O+SL**"@D<')O
M9VYA;64@/2`B)&1I<B1S>7-[7V1E;&EM?21P<F]G;F%M921S>7-[7V5X97TB
M*2P@;&%S="D*:68@+7,@(B1D:7(D<WES>U]D96QI;7TD<')O9VYA;64D<WES
M>U]E>&5](CL**"@D<')O9VYA;64@/2`B)&1I<B1S>7-[7V1E;&EM?21P<F]G
M;F%M92(I+"!L87-T*0II9B`M<R`B)&1I<B1S>7-[7V1E;&EM?21P<F]G;F%M
M92(["GT*?0IS=6(@7V9I>%]P<F]G;F%M92!["B0P(#T@)'!R;V=N86UE('Q\
M/2`D14Y6>U!!4E]04D]'3D%-17T["FEF("AI;F1E>"@D<')O9VYA;64L("1S
M>7-[7V1E;&EM?2D@/"`P*2!["B1P<F]G;F%M92`]("(N)'-Y<WM?9&5L:6U]
M)'!R;V=N86UE(CL*?0IM>2`D<'=D(#T@*&1E9FEN960@)D-W9#HZ9V5T8W=D
M*2`_($-W9#HZ9V5T8W=D*"D*.B`H*&1E9FEN960@)E=I;C,R.CI'971#=V0I
M(#\@5VEN,S(Z.D=E=$-W9"@I(#H@8'!W9&`I.PIC:&]M<"@D<'=D*3L*)'!R
M;V=N86UE(#U^(',O7B@_/5PN7"X_7%$D<WES>U]D96QI;7U<12DO)'!W9"1S
M>7-[7V1E;&EM?2\["B1%3E9[4$%27U!23T=.04U%?2`]("1P<F]G;F%M93L*
M?0IS=6(@7W!A<E]I;FET7V5N=B!["FEF("@@)$5.5GM005)?24Y)5$E!3$E:
M141]*RL@/3T@,2`I('L*<F5T=7)N.PI](&5L<V4@>PHD14Y6>U!!4E])3DE4
M24%,25I%1'T@/2`R.PI]"F9O<B`H<7<H(%-005=.140@5$5-4"!#3$5!3B!$
M14)51R!#04-(12!04D]'3D%-12`I("D@>PID96QE=&4@)$5.5GLB4$%27R1?
M(GT["GT*9F]R("AQ=R\@5$U01$E2(%1%35`@0TQ%04X@1$5"54<@+RD@>PHD
M14Y6>R)005)?)%\B?2`]("1%3E9[(E!!4E]'3$]"04Q?)%\B?2!I9B!E>&ES
M=',@)$5.5GLB4$%27T=,3T)!3%\D7R)].PI]"FEF("@D14Y6>U!!4E]414U0
M?2D@>PID96QE=&4@)$5.5GM005)?0TQ%04Y].PI]"GT*<W5B(&]U=',@>PIR
M971U<FX@:68@)'%U:65T.PII9B`H)&QO9V9H*2!["G!R:6YT("1L;V=F:"`B
M0%]<;B(["GT*96QS92!["G!R:6YT(")`7UQN(CL*?0I]"G-U8B!I;FET7VEN
M8R!["G)E<75I<F4@0V]N9FEG.PIP=7-H($!)3D,L(&=R97`@9&5F:6YE9"P@
M;6%P("1#;VYF:6<Z.D-O;F9I9WLD7WTL('%W*`IA<F-H;&EB97AP('!R:79L
M:6)E>'`@<VET96%R8VAE>'`@<VET96QI8F5X<`IV96YD;W)A<F-H97AP('9E
M;F1O<FQI8F5X<`HI.PI]"G!A8VMA9V4@;6%I;CL*<F5Q=6ER92!005(["G5N
M<VAI9G0@0$E.0RP@7"9005(Z.F9I;F1?<&%R.PI005(M/FEM<&]R="A`<&%R
M7V%R9W,I.PID:64@<7%;<&%R+G!L.B!#86XG="!O<&5N('!E<FP@<V-R:7!T
M("(D<')O9VYA;64B.B!.;R!S=6-H(&9I;&4@;W(@9&ER96-T;W)Y7&Y="G5N
M;&5S<R`M92`D<')O9VYA;64["F1O("1P<F]G;F%M93L*0T]213HZ97AI="@D
M,2D@:68@*"1`(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("1`(&EF
M("1`.PI].PHD.CI?7T524D]2(#T@)$`@:68@)$`["GT*0T]213HZ97AI="@D
M,2D@:68@*"0Z.E]?15)23U(@/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I.PID
M:64@)#HZ7U]%4E)/4B!I9B`D.CI?7T524D]2.PHQ.PI?7T5.1%]?"@`!&P,[
M"`$``"`````XC___(`$``)B/__]$`0``()#__VP!``#0D?__U`$``+B2__\`
M`@``8)/__S`"``#`E/__9`(``/B6__^<`@``B)?__\@"``"DF/__``,``)R9
M__\\`P``!)K__W0#``!\FO__G`,``(2:__^P`P```)W__^0#```PG?__%`0`
M`)"=__]8!```7)___X@$``#<G___L`0``#R@___8!```'*+__Q`%```\HO__
M,`4``#"C__]D!0``U*G__YP%``!DK/__T`4``,BL__\P!@``S+C__V@&```P
MN?__B`8``$BZ__^T!@``O+O__Z0!``!$O/__D`$``)B\__\`!@``$```````
M```!>E(``GP.`1L,#0`@````&````!".__]@`````$0-#$R$!H4%BP2-`XX"
M0@P+!``D````/````$R.__^(`````$0-#$B$"(4'A@:'!8L$C0..`D(,"P0`
M(````&0```"LCO__L`$```!&#0Q$AP6+!(T#C@)"#`L$````$````(@```"L
MNO__5``````````L````G````!"Z__^(`````$0-#$2$!H4%BP2-`XX"1`P+
M!&@,#1A"SLW+Q<0.!``H````S````/2/___H`````$(-#$2$"H4)A@B'!X@&
MB06+!(T#C@)$#`L$`"P```#X````L)#__Z@`````0@T,1(0(A0>&!H<%BP2-
M`XX"0@P+!`)""@P-($(+`#`````H`0``*)'__V`!````1`T,1H0+A0J&"8<(
MB`>)!HH%BP2-`XX"0@P+!%P*#`TL0@LT````7`$``%22__\X`@```$(-#$2$
M"X4*A@F'"(@'B0:*!8L$C0..`D(,"P0"E@H,#2Q""P```"@```"4`0``5)3_
M_Y``````1`T,1H0&A06+!(T#C@)"#`L$:`H,#1A""P``-````,`!``"XE/__
M'`$```!$#0Q"A`N%"H8)APB(!XD&B@6+!(T#C@)"#`L$`E@*#`TL0@L````X
M````^`$``)R5___X`````$0-#$*$!H4%BP2-`XX"0@P+!`)8"@P-&$(+3@H,
M#1A"SLW+Q<0.!$(+```T````-`(``%B6__]H`````$0-#$B$"(4'A@:'!8L$
MC0..`D(,"P18#`T@0L[-R\?&Q<0.!````"0```!L`@``B);__W@`````1`T,
M1(0&A06+!(T#C@)$#`L$9`P-&``0````E`(``-B6__\(`````````#````"H
M`@``S);__WP"````1`T,1H0+A0J&"8<(B`>)!HH%BP2-`XX"1`P+!'P*#`TL
M0@LL````W`(``!29__\P`````$(-#$2$!H4%BP2-`XX"0@P+!$P,#1A"SLW+
MQ<0.!`!`````#`,``!29__]@`````$(-#$*$!H4%BP2-`XX"1`P+!%0*#`T8
M0L[-R\7$#@1""T8*#`T80L[-R\7$#@1""P```"P```!0`P``,)G__\P!````
M1`T,2(0'A0:&!8L$C0..`D(,"P0"E`H,#1Q""P```"0```"``P``S)K__X``
M````1`T,2(0%BP2-`XX"0@P+!&@*#`T40@LD````J`,``"2;__]@`````$(-
M#$*`!($#@@*#`42+"(T'C@9"#`L4-````-`#``!<F___X`$```!$#0Q"A`N%
M"H8)APB(!XD&B@6+!(T#C@)"#`L$`K0*#`TL0@L````<````"`0```2=__\@
M`````$(-#$*+!(T#C@)"#`L$`#`````H!```!)W___0`````1`T,1H0)A0B&
M!X<&B`6+!(T#C@)"#`L$`EX*#`TD0@L````T````7`0``,2=__^D!@```$(-
M#$2$"X4*A@F'"(@'B0:*!8L$C0..`D(,"P0#.`$*#`TL0@L``#````"4!```
M,*3__Y`"````1`T,2(0)A0B&!X<&B`6+!(T#C@)"#`L$`M(*#`TD0@L````L
M````R`0``(RF__]D`````$(-#$*$!H4%BP2-`XX"0@P+!&8,#1A"SLW+Q<0.
M!``L````^`0``)"V__^0`@```$(-#$2$"(4'A@:'!8L$C0..`D(,"P0"S`H,
M#2!""P`T````*`4``)"F__\$#````$0-#$2$"X4*A@F'"(@'B0:*!8L$C0..
M`D0,"P0#[@4*#`TL0@L``!P```!@!0``7++__V0`````0@T,1(L$C0..`D(,
M"P0`*````(`%``"@LO__&`$```!"#0Q"A`J%"88(AP>(!HD%BP2-`XX"7@P+
M!``\````K`4``(RS__]T`0```$(-#$*$"H4)A@B'!X@&B06+!(T#C@)2#`L$
M`I@*#`TH0L[-R\G(Q\;%Q`X$0@L``````/1#``!L0P````````$````!````
M`0```,L"```!````U0(```$```#C`@```0````D#```/````H@0``!D```"H
MC@$`&P````0````:````K(X!`!P````$````!````'@!```%````=`L```8`
M``"T!```"@```.L$```+````$````!4``````````P```*2/`0`"````&`(`
M`!0````1````%P```(@1```1````8!```!(````H`0``$P````@```#[__]O
M````"/K__V\9````````````````````````````````````````````````
M`````````+2.`0```````````*`3``"@$P``H!,``*`3``"@$P``H!,``*`3
M``"@$P``H!,``*`3``"@$P``H!,``*`3``"@$P``H!,``*`3``"@$P``H!,`
M`*`3``"@$P``H!,``*`3``"@$P``H!,``*`3``"@$P``H!,``*`3``"@$P``
MH!,``*`3``"@$P``H!,``*`3``"@$P``H!,``*`3``"@$P``H!,``*`3``"@
M$P``H!,``*`3``"@$P``H!,``*`3``"@$P``H!,``*`3``"@$P``H!,``*`3
M``"@$P``H!,``*`3``"@$P``H!,``*`3``"@$P``H!,``*`3``"@$P``H!,`
M`*`3``"@$P``H!,``*`3``"PC@$``````'@1````````J(X!````````````
M`````,"1`0!X$0```````*R.`0``````7)$!`````````````````+2.`0``
M````A)$!```````8D0$`A#$``("1`0`<D0$`"E!!4BYP;0H`````.$H```!'
M````````$$@``!1(```L2@``7$<``#1*````````&$H``"!*````````0$H`
M`$=#0SH@*$YE=$)31"!N8C0@,C`R,#`X,3`I(#<N-2XP`$=#0SH@*&YB-"`R
M,#(P,#@Q,"D@-RXU+C``)$YE=$)31#H@8W)T,"Y3+'8@,2XT(#(P,3@O,3$O
M,C8@,3<Z,S<Z-#0@:F]E<F<@17AP("0`)$YE=$)31#H@8W)T,"UC;VUM;VXN
M8RQV(#$N,C,@,C`Q."\Q,B\R."`R,#HQ,CHS-2!C:')I<W1O<R!%>'`@)``D
M3F5T0E-$.B!C<G1I+E,L=B`Q+C$@,C`Q,B\P."\Q,R`P,CHT.3HP-"!M871T
M($5X<"`D`"1.971"4T0Z(&-R=&)E9VEN+F,L=B`Q+C$W(#(P,3@O,3(O,C@@
M,3@Z,3<Z,3$@8VAR:7-T;W,@17AP("0`)$YE=$)31#H@8W)T96YD+E,L=B`Q
M+C(@,C`Q,R\Q,B\R,"`Q-3HS-3HT."!J;V5R9R!%>'`@)`````#QSP(`````
M````````````"`````@````(````"````!L````!```````````J*BH@3F\@
M3&%B96P@4')O=FED960@*BHJ``#QSP(`````````````````"`````@````(
M````"````!L````!```````````J*BH@3F\@3&%B96P@4')O=FED960@*BHJ
M`$$V````865A8FD``2P````%0V]R=&5X+4$X``8*!T$(`0D""@(2!!0!%0$7
M`Q@!&@(<`2(!1`$`+G-H<W1R=&%B`"YI;G1E<G``+FYO=&4N;F5T8G-D+FED
M96YT`"YN;W1E+FYE=&)S9"YP87@`+FYO=&4N;F5T8G-D+FUA<F-H`"YH87-H
M`"YD>6YS>6T`+F1Y;G-T<@`N<F5L+F1Y;@`N<F5L+G!L=``N=&5X=``N<F]D
M871A`"YE:%]F<F%M95]H9'(`+F5H7V9R86UE`"YI;FET7V%R<F%Y`"YF:6YI
M7V%R<F%Y`"YJ8W(`+F1Y;F%M:6,`+F=O=``N9&%T80`N8G-S`"YC;VUM96YT
M`"Y354Y77V-T9@`N05)-+F%T=')I8G5T97,`````````````````````````
M```````````````````````````````+`````0````(````4`0``%`$``!<`
M``````````````$`````````$P````<````"````+`$``"P!```8````````
M```````$`````````"8````'`````@```$0!``!$`0``%```````````````
M!``````````W````!P````(```!8`0``6`$``"````````````````0`````
M````2@````4````"````>`$``'@!```\`P``!@`````````$````!````%``
M```+`````@```+0$``"T!```P`8```<````#````!````!````!8`````P``
M``(```!T"P``=`L``.L$``````````````$`````````8`````D````"````
M8!```&`0```H`0``!@`````````$````"````&D````)````0@```(@1``"(
M$0``&`(```8````3````!`````@```!M`````0````8```"@$P``H!,``#@#
M``````````````0````$````<@````$````&````V!8``-@6````,```````
M```````$`````````'@````!`````@```-A&``#81@``V$``````````````
M!`````````"``````0````(```"PAP``L(<```P!``````````````0`````
M````C@````$````"````O(@``+R(``#L!0`````````````$`````````)@`
M```.`````P```*B.`0"HC@``!```````````````!`````0```"D````#P``
M``,```"LC@$`K(X```0```````````````0````$````L`````$````#````
ML(X!`+".```$```````````````$`````````+4````&`````P```+2.`0"T
MC@``\`````<`````````!`````@```"^`````0````,```"DCP$`I(\``'0!
M``````````````0````$````PP````$````#````&)$!`!B1``!(````````
M```````$`````````,D````(`````P```("1`0!@D0``1```````````````
M0`````````#.`````0```#``````````8)$``#L```````````````$````!
M````'P````$``````````````)N1```B`0`````````````!`````````-<`
M```!``````````````#`D@``CP``````````````!`````````#A`````P``
M<```````````3Y,``#<```````````````$``````````0````,`````````
<`````(:3``#Q```````````````!````````````
